;;
;;  File: en971128.glm
;;  Desc: This file contains the transcript filtering rules for the ARPA
;;        Hub4-E and Hub5-E Evaluations.  This file originated from 
;;        et96_1.glm.
;;
;;  Date: 970904
;;        - initial creation 
;;  Date: 971128
;;        - added Hub-4E evaluation contractions
;;
* name "en971128.glm"
* desc "The Universal GLM file for the ARPA Hub4-E and Hub5-E Eval Test Alternate Spellings and Contractions Map"
* format = 'NIST1'
* max_nrules = '1512'
* copy_no_hit = 'T'
* case_sensitive = 'F'
;; File spellalt6.rls Version 6.0 dated 11/21/97
;;
;; Standard alternate spellings, usually per AHD
;; meant to apply to SNOR transcriptions.
;;
'CAUSE             => BECAUSE ;; per AHD
'EM                => THEM ;; per AHD
'TIL               => TILL ;; not exactly per AHD, but common
;;
;; Unambiguously handle mr. mrs. and ms.
MR                 => MISTER / [ ] __ [ ] 
MR.                => MISTER / [ ] __ [ ] 
MRS.               => MRS / [ ] __ [ ] 
MS.                => MS / [ ] __ [ ] 
;; actually, "adviser' is preferred, but doing it this way
;; avoids misspelling "advisory":
ADVISER            => ADVISOR / [ ] __ 
AFTERALL           => AFTER ALL ;; per AHD
ALRIGHT            => ALL RIGHT ;; "alright" is nonstandard per AHD
BAGDAD             => BAGHDAD ;; per AHD
BALLGAME           => BALL GAME ;; PER AHD
BASELINE           => BASE LINE ;; WWW hits
BAZAR              => BAZAAR ;; per AHD
BENEFITTED         => BENEFITED ;; per AHD
BENEFITTING        => BENEFITING ;; per AHD
BINYAMIN           => BENJAMIN / __ [ NETANYAHU]
BUILDUP            => BUILD UP ;; WWW hits
CAMELBACK          => CAMEL BACK ;; literally; AHD is silent
CANCELLATION       => CANCELATION ;; per AHD
CANCELLED          => CANCELED ;; per AHD
CANCELLING         => CANCELING ;; per AHD
CATALOGUE          => CATALOG ;; per AHD
CEASEFIRE          => CEASE FILE ;; per AHD
CHANNELLING        => CHANNELING ;; per AHD
CHANNELLED         => CHANNELED ;; per AHD
COFOUNDER          => CO FOUNDER ;; not found in AHD
COMBATTED          => COMBATED ;; per AHD
COMBATTING         => COMBATING ;; per AHD
COLOSSEUM          => COLISEUM ;; per AHD
COUNSELLOR         => COUNSELOR ;; per AHD
COUNSELLED         => COUNSELED ;; per AHD
COUNSELLING        => COUNSELING ;; per AHD
COVERUP            => COVER UP ;; per AHD, with hyphen
CSAR               => CZAR ;; WWW hits
DAYCARE            => DAY CARE ;; per AHD
DEPALMA            => DE PALMA ;; Brian _
DEUTSCHEMARK       => DEUTSCHE MARK ;; per AHD
DISFUNCTION        => DYSFUNCTION ;; per AHD
DONUT              => DOUGHNUT ;; per AHD
DOWN SYNDROME      => DOWN'S SYNDROME ;; per AHD
DUNKERQUE          => DUNKIRK ;; per AHD
ENDGAME            => END GAME ;; per AHD
ESTHETIC           => AESTHETIC / [ ] __ ;; per AHD
FALKNER            => FAULKNER / [WILLIAM ] __  ;; the writer, per AHD
FALLOUT            => FALL OUT ;; WWW hits
FATIMAH            => FATIMA ;; per AHD
FIREFIGHTER        => FIRE FIGHTER ;; per AHD
FIREFIGHTERS       => FIRE FIGHTERS ;; per AHD
FO'C'SLE           => FORECASTLE ;; per AHD
FOCUSSED           => FOCUSED ;; per AHD
FOCUSSES           => FOCUSES ;; per AHD
FOCUSSING          => FOCUSING ;; per AHD
FOLLOWUP           => FOLLOW UP ;; per AHD, with a hyphen
FREELANCE          => FREE LANCE ;; per AHD
FRONTLINE          => FRONT LINE ;; per AHD (adj is also front-line)
FTSE               => FOOTSIE
FT SE              => FOOTSIE ;; officially spelled w/hyphen
FUNDRAIS           => FUND RAIS ;; per AHD (actually "fund-raiser")
;; applies to fundraiser, fundraising, etc.
FUNELLED           => FUNELED  ;; per AHD
FUNELLING          => FUNELING  ;; per AHD
GADDAFI            => QADDHAFI ;; per AHD
GELATINE           => GELATIN ;; per AHD
GENNADI            => GENNADY ;; Russian transliteration not 100% fixed
GOODBYE            => GOOD BYE ;; per AHD (actually "good-bye")
GOOD BY            => GOOD BYE ;; per AHD (actually "good-by")
;;GOODNIGHT          => GOOD NIGHT ;; check other dicts; AHD is silent on this
HARDLINE           => HARD LINE ;; per AHD (adj or stem-r only)
HEALTHCARE         => HEALTH CARE ;; per AHD
HEALTHDESK         => HEALTH DESK ;; NPR spells theirs as 1 word
HIZBOLLAH          => HEZBOLLAH ;; WWW hits
HOTLINE            => HOT LINE ;; per AHD
JETLINER           => JET LINER ;; per AHD
JOHNNY-COME-LATELYS => JOHNNY-COME-LATELIES ;; per AHD
KADDAFI            => QADDAFI ;; per AHD
KEYWORD            => KEY WORD ;; per AHD
KHADAFY            => QADDAFI ;; per AHD
KIPPAH             => KIPAH ;; WWW hits
KNOCKOFF           => KNOCK OFF ;; WWW hits
LAGUARDIA          => LA GUARDIA ;; WWW hits, altho AHD has only 2-word form
LIFTGATE           => LIFT GATE ;; eq. hits on WWW
LOONEY             => LOONY ;; per AHD
MA'ARIV            => MAARIV ;; WWW hits
MAKEUP             => MAKE UP ;; actually hyphenated, per AHD
MARKETPLACE        => MARKET PLACE ;; per AHD
MIKASUKI           => MICCOSUKEE ;; per AHD
MINDSET            => MIND SET ;; actually hyphenated per AHD
MISLABELLED        => MISLABELED ;; per AHD
MISLABELLING       => MISLABELING ;; per AHD
MONTHLONG          => MONTH LONG ;; WWW hits, hyphenated
NEWSHOUR           => NEWS HOUR ;; WWW hits, but ?? (Lehrer's is only 1 word)
NEWSROOM           => NEWS ROOM ;; WWW hits
NONECONOMIC        => NON ECONOMIC ;; WWW hits
OK                 => OKAY / [ ] __ [ ] ;; per AHD (also O.K.)
;; but we can't allow o.k. because it may mean Oklahoma
ONBOARD            => ON BOARD ;; per AHD, with hyphen
OSHKOSH            => OSH KOSH ;; many net hits both ways
OVERPOLL           => OVER POLL ;; neologism
PAPERWORK          => PAPER WORK ;; per AHD
PERCENT            => PER CENT ;; per AHD
PIROGHI            => PIROGI ;; per AHD
PLAYOFF            => PLAY OFF ;; actually hyphenated per AHD
POSTCARD           => POST CARD ;; per AHD
PRIMETIME          => PRIME TIME ;; per AHD, noun-2 words, adj-hyphenated
PROGRAMED          => PROGRAMMED ;; per AHD
PROGRAMER          => PROGRAMMER ;; per AHD
PROGRAMING         => PROGRAMMING ;; per AHD
QADHAFI            => QADDAFI ;; WWW HITS
REBURY             => RE BURY ;; WWW hits
REELECT            => RE ELECT ;; per AHD, with hyphen
REENFORC           => RE ENFORC ;; per AHD, with hyphen
REENTER            => RE ENTER ;; per AHD, with hyphen
REEXAMIN           => RE EXAMIN ;; per AHD, with hyphen
REHOSPITAL         => RE HOSPITAL ;; WWW hits
REIMAGINE          => RE IMAGINE ;; WWW hits
RIVALING           => RIVALLING ;; per AHD
ROADMAP            => ROAD MAP ;; per AHD
ROUNDTABLE         => ROUND TABLE ;; per AHD, w/ or w/o hyphen
SABRETECH          => SABRE TECH ;; both ways on WWW
SANDIEGO           => SAN DIEGO ;; per AHD, two words
SHABUOTH           => SHAVUOT ;; per AHD
SHIAH              => SHIA ;; per AHD
SHOOTOUT           => SHOOT OUT ;; per AHD, with hyphen
SIZEABLE           => SIZABLE ;; per AHD
SNOWSHOWERS        => SNOW SHOWERS ;; AHD is silent on this one
SPINOFF            => SPIN OFF ;; per AHD, with hyphen
SUPERBOWL          => SUPER BOWL ;; 1 word 38k, 2 words 70k WWW hits
SUPERFIGHTER       => SUPER FIGHTER ;; AHD silent; about eq WWW hits
T.                 => TEE / __ [ SHIRT] ;; per AHD, with hyphen
TAIPEH             => TAIPEI ;; per AHD
TAKEOVER           => TAKE OVER ;; per AHD, with hyphen
TEENAGE            => TEEN AGE ;; per AHD, with hyphen
THROUGHWAY         => THRUWAY ;; in particular, the NY State ___
TORNADOES          => TORNADOS ;; PER AHD
TSAR               => CZAR ;; WWW hits
TZAR               => CZAR ;; WWW hits
UNDERWAY           => UNDER WAY ;; per AHD
VINCENTS           => VINCENT'S / [SAINT ] __  ;; possessives often drop from names
WALMART            => WAL MART ;; WWW hits, butoffically 2 wrds w/hyphen
WHIMSEY            => WHIMSY ;; per AHD
WHISTLEBLOWER      => WHISTLE BLOWER ;; per AHD
WHITEWATER         => WHITE WATER ;; see it both ways -- no standard
WILFUL             => WILLFULL ;; per AHD
WORKFORCE          => WORK FORCE ;; per AHD
WORKPLACE          => WORK PLACE ;; per AHD
WORKSHEET          => WORK SHEET ;; per AHD
WORLDVIEW          => WORLD VIEW ;; per AHD, with hyphen
YASSER             => YASIR ;; per AHD, but alt common on web
YASSIR             => YASIR ;; per AHD, but alt common on web
ZAIREAN            => ZAIRIAN ;; per AHD
ZUGANOV            => ZYUGANOV ;; Russian transliteration not 100% fixed
;; end of standard_alt_spellings.rls
;;
;; File uncertain_compound_words.rls Version 2 dated 12/13/96
;;
;; Rules for mapping alternate spellings of some
;; compound words into just one form, for scoring.
;; For these words, I'm not sure what the "correct"
;; form is.
;;
;; - W. M. Fisher, 12/10/96
[AIRWING]            => [AIR WING]
[BEANCOUNTER]        => [BEAN COUNTER]
[BUTTHEAD]           => [BUTT HEAD]
[CANNOT ]            => [CAN NOT ]
[HOMEPAGE]           => [HOME PAGE]
[PHOTOCALL]          => [PHOTO CALL]
[DUMPTRUCK]          => [DUMP TRUCK]
[GUNBATTLE]          => [GUN BATTLE]
[GOODMORNING AMERICA ] => [GOOD MORNING AMERICA ] ;; see it both ways on Web
;;[GUNNYSACK ]          => [GUNNY SACK ] ;; 1 word per AHD, but I've often seen it hyphenated
[TRAINSPOTTING ]     => [TRAIN SPOTTING ]
[WEBSITE]            => [WEB SITE]
;; end of uncertain_compound_words.rls
;; File training_errs.rls Version 3 dated 12/12/96
;;
;; Rules to apply to REF and HYP LSN transcriptions
;; in scoring to compensate for errors in the
;; training data for the 1996 CSR Hub4 evaluations.
;; Generally speaking, if a certain word occurs
;; in the official training data (which includes
;; the American Heritage Dictionary, AHD) sometimes
;; spelled X and sometimes Y, the difference between
;; X and Y will not be counted an error in the
;; evaluation test.  This forgiveness will not
;; be done, however, in cases of typos
;; that result in a valid word spelling.
;;
;; - Jon Fiscus & Bill Fisher, 12/10/96
;;
;; Note - the left hand and right hand sides of
;; many-to-one rules have been interchanged
;; in order to give a finer grain to scoring, even
;; when the single token is in fact the correct version.
;; Because of this, these rules are *not* appropriate
;; to be used to correct transcriptions in general!
;; The original rules which map incorrect versions into
;; correct versions have been kept around as comments
;; when they are materially different.
;;
;; - W. M. Fisher, 11/06/96
;;
;; compound words:
;; valid-word typo AGREED            => A GREED          / [ ] __ [ ]
 AIRBAG            => AIR BAG          / [ ] __ [ ]
 AIRBAGS           => AIR BAGS         / [ ] __ [ ]
 AIRCRAFT          => AIR CRAFT        / [ ] __ [ ]
 AIRCREW           => AIR CREW         / [ ] __ [ ]
 AIRLINE'S         => AIR LINE'S       / [ ] __ [ ]
 AIRTIGHT          => AIR TIGHT        / [ ] __ [ ]
 AIRFORCE          => AIR FORCE        / [ ] __ [ ]
 ALFAVILLI         => ALFA VILLI       / [ ] __ [ ]
 ANSANG            => UNG SUN          / [ ] __ [ ]
 ANTIABORTION      => ANTI ABORTION    / [ ] __ [ ]
 ANYMORE           => ANY MORE         / [ ] __ [ ]
 ANYTIME           => ANY TIME         / [ ] __ [ ]
 ARTWORK           => ART WORK         / [ ] __ [ ]
 AUTOMAKERS        => AUTO MAKERS      / [ ] __ [ ]
 AUTOMOTIVE        => AUTO MOTIVE      / [ ] __ [ ]
;; valid-word typo  AWHILE            => A WHILE          / [ ] __ [ ]
 BACKSEAT          => BACK SEAT        / [ ] __ [ ]
 BACKUP            => BACK UP          / [ ] __ [ ]
 BALLPARK          => BALL PARK        / [ ] __ [ ]
 BANDWAGON         => BAND WAGON       / [ ] __ [ ]
 BELTWAY           => BELT WAY         / [ ] __ [ ]
 BENCHMARK         => BENCH MARK       / [ ] __ [ ]
 BIOHAZARD         => BIO HAZARD       / [ ] __ [ ]
 BITTERSWEET       => BITTER SWEET     / [ ] __ [ ]
 BLUEPRINT         => BLUE PRINT       / [ ] __ [ ]
 BOARDWALK         => BOARD WALK       / [ ] __ [ ]
 BOOKSTORES        => BOOK STORES      / [ ] __ [ ]
 BREAKAWAY         => BREAK AWAY       / [ ] __ [ ]
 BUSINESSMAN       => BUSINESS MAN     / [ ] __ [ ]
 BUSINESSMEN       => BUSINESS MEN     / [ ] __ [ ]
 BUSINESSPEOPLE    => BUSINESS PEOPLE  / [ ] __ [ ]
 CEASEFIRE         => CEASE FIRE       / [ ] __ [ ]
 CENTERPIECE       => CENTER PIECE     / [ ] __ [ ]
 CHILDCARE         => CHILD CARE       / [ ] __ [ ]
 COPYCAT           => COPY CAT         / [ ] __ [ ]
 COUNTDOWN         => COUNT DOWN       / [ ] __ [ ]
 COUNTRYSIDE       => COUNTRY SIDE     / [ ] __ [ ]
 COURTHOUSE        => COURT HOUSE      / [ ] __ [ ]
 CRACKDOWN         => CRACK DOWN       / [ ] __ [ ]
 CROSSFIRE         => CROSS FIRE       / [ ] __ [ ]
 DAYCARE           => DAY CARE         / [ ] __ [ ]
 DAYTIME           => DAY TIME         / [ ] __ [ ]
 DEPALMA           => DE PALMA         / [ ] __ [ ]
 DEPALMA'S         => DE PALMA'S       / [ ] __ [ ]
 DRAGONHEART       => DRAGON HEART     / [ ] __ [ ]
 DRUMBEAT          => DRUM BEAT        / [ ] __ [ ]
 ETCETERA          => ET CETERA        / [ ] __ [ ]
 EVERYONE          => EVERY ONE        / [ ] __ [ ]
 EYEWITNESS        => EYE WITNESS      / [ ] __ [ ]
 EYEWITNESSES      => EYE WITNESSES    / [ ] __ [ ]
 EVERYDAY          => EVERY DAY        / [ ] __ [ ]
 FALLOUT           => FALL OUT         / [ ] __ [ ]
 FARMHOUSE         => FARM HOUSE       / [ ] __ [ ]
 FERRYBOAT         => FERRY BOAT       / [ ] __ [ ]
 FINGERPRINT       => FINGER PRINT     / [ ] __ [ ]
 FINGERPRINTS      => FINGER PRINTS    / [ ] __ [ ]
 FIREARMS          => FIRE ARMS        / [ ] __ [ ]
 FLATBED           => FLAT BED         / [ ] __ [ ]
 FOREFRONT         => FORE FRONT       / [ ] __ [ ]
 FREELANCE         => FREE LANCE       / [ ] __ [ ]
 FREESTYLE         => FREE STYLE       / [ ] __ [ ]
 GIVEAWAY          => GIVE AWAY        / [ ] __ [ ]
 GOODNIGHT         => GOOD NIGHT       / [ ] __ [ ]
 GRASSROOTS        => GRASS ROOTS      / [ ] __ [ ]
 GRIDLOCK          => GRID LOCK        / [ ] __ [ ]
 GUNSHOT           => GUN SHOT         / [ ] __ [ ]
 HALLWAY           => HALL WAY         / [ ] __ [ ]
 HEALTHCARE        => HEALTH CARE      / [ ] __ [ ]
 HEARTFELT         => HEART FELT       / [ ] __ [ ]
 HOMELAND          => HOME LAND        / [ ] __ [ ]
 HOMEMADE          => HOME MADE        / [ ] __ [ ]
 HOMETOWN          => HOME TOWN        / [ ] __ [ ]
 HOTLINE           => HOT LINE         / [ ] __ [ ]
 HOWEVER           => HOW EVER         / [ ] __ [ ]
;; valid-word typo  INSTEAD           => IN STEAD         / [ ] __ [ ]
;; inter-connect      => interconnect ;; 1 word per AHD
;; inter connect      => interconnect ;; 1 word per AHD
 INTERCONNECT      => INTER CONNECT    / [ ] __ [ ] ;; 1 word per AHD (2 in c960516)
;; valid-word typo  INTO              => IN TO            / [ ] __ [ ]
 INTERRACIAL       => INTER RACIAL     / [ ] __ [ ]
 KEYWORD           => KEY WORD         / [ ] __ [ ]
 LAWMAKERS         => LAW MAKERS       / [ ] __ [ ]
 LAWSUIT           => LAW SUIT         / [ ] __ [ ]
 LAWSUITS          => LAW SUITS        / [ ] __ [ ]
 LAYOFFS           => LAY OFFS         / [ ] __ [ ]
 LIFESPAN          => LIFE SPAN        / [ ] __ [ ]
 LIFETIME          => LIFE TIME        / [ ] __ [ ]
 LOPSIDED          => LOP SIDED        / [ ] __ [ ]
 MAINSTREAM        => MAIN STREAM      / [ ] __ [ ]
 MAKEUP            => MAKE UP          / [ ] __ [ ]
 MANPOWER          => MAN POWER        / [ ] __ [ ]
 MARKETPLACE       => MARKET PLACE     / [ ] __ [ ]
 MARKETPLACE'S     => MARKET PLACE'S   / [ ] __ [ ]
 MICROBIOLOGY      => MICRO BIOLOGY    / [ ] __ [ ]
 MIDEAST           => MID EAST         / [ ] __ [ ]
 MIDTOWN           => MID TOWN         / [ ] __ [ ]
 MINDSET           => MIND SET         / [ ] __ [ ]
 MOTORBOAT         => MOTOR BOAT       / [ ] __ [ ]
 NATIONWIDE        => NATION WIDE      / [ ] __ [ ]
 NETAN YAHU'S      => NETANYAHU'S      / [ ] __ [ ]
 NEWSPAPER         => NEWS PAPER       / [ ] __ [ ]
 NEWSROOM          => NEWS ROOM        / [ ] __ [ ]
 NEWSWEEK          => NEWS WEEK        / [ ] __ [ ]
 NIGHTLINE         => NIGHT LINE       / [ ] __ [ ]
 NOWHERE           => NO WHERE         / [ ] __ [ ]
 NONEXISTENT       => NON EXISTENT     / [ ] __ [ ]
 NONPROFIT         => NON PROFIT       / [ ] __ [ ]
 NONSTOP           => NON STOP         / [ ] __ [ ]
 NORTHEAST         => NORTH EAST       / [ ] __ [ ]
 NORTHWEST         => NORTH WEST       / [ ] __ [ ]
 ONGOING           => ON GOING         / [ ] __ [ ]
 ONETIME           => ONE TIME         / [ ] __ [ ]
;; valid-word typo ONTO              => ON TO            / [ ] __ [ ]
 OUTDATED          => OUT DATED        / [ ] __ [ ]
 OUTPLACEMENT      => OUT PLACEMENT    / [ ] __ [ ]
 OUTRIGHT          => OUT RIGHT        / [ ] __ [ ]
 OVERALL           => OVER ALL         / [ ] __ [ ]
 OVERBUILT         => OVER BUILT       / [ ] __ [ ]
 OVERCROWDING      => OVER CROWDING    / [ ] __ [ ]
 OVERHAUL          => OVER HAUL        / [ ] __ [ ]
 OVERHEAT          => OVER HEAT        / [ ] __ [ ]
 OVERNIGHT         => OVER NIGHT       / [ ] __ [ ]
 OVERSEAS          => OVER SEAS        / [ ] __ [ ]
 OVERSHADOWED      => OVER SHADOWED    / [ ] __ [ ]
 OVERSIGHT         => OVER SIGHT       / [ ] __ [ ]
 PAPERWORK         => PAPER WORK       / [ ] __ [ ]
 PAYBACK           => PAY BACK         / [ ] __ [ ]
 PEACEKEEPERS      => PEACE KEEPERS    / [ ] __ [ ]
 PEACEKEEPING      => PEACE KEEPING    / [ ] __ [ ]
;; valid-word typo  PERCENT           => PER CENT         / [ ] __ [ ]
 PLAYOFFS          => PLAY OFFS        / [ ] __ [ ]
 POLICEWOMAN       => POLICE WOMAN     / [ ] __ [ ]
 POSTCARDS         => POST CARDS       / [ ] __ [ ]
 PREDAWN           => PRE DAWN         / [ ] __ [ ]
 PREPAID           => PRE PAID         / [ ] __ [ ]
 PRETEEN           => PRE TEEN         / [ ] __ [ ]
 ROADMAP           => ROAD MAP         / [ ] __ [ ]
 ROBINHOOD         => ROBIN HOOD       / [ ] __ [ ]
 ROLLBACK          => ROLL BACK        / [ ] __ [ ]
 RUNOFF            => RUN OFF          / [ ] __ [ ]
 SCARECROW         => SCARE CROW       / [ ] __ [ ]
 SCHOOLBUS         => SCHOOL BUS       / [ ] __ [ ] ;; 2 words per AHD
 SCHOOLBUSES       => SCHOOL BUSES     / [ ] __ [ ] ;; 2 words per AHD
 SCHOOLHOUSE       => SCHOOL HOUSE     / [ ] __ [ ]
 SCORECARD         => SCORE CARD       / [ ] __ [ ]
 SCOREKEEPING      => SCORE KEEPING    / [ ] __ [ ]
 SEATBELT          => SEAT BELT        / [ ] __ [ ]
 SETBACK           => SET BACK         / [ ] __ [ ]
 SHOOTOUT          => SHOOT OUT        / [ ] __ [ ]
 SHORTCAKE         => SHORT CAKE       / [ ] __ [ ]
 SHOWBIZ           => SHOW BIZ         / [ ] __ [ ]
 SIDELINE          => SIDE LINE        / [ ] __ [ ]
 SIDESTEPPING      => SIDE STEPPING    / [ ] __ [ ]
 SKYROCKET         => SKY ROCKET       / [ ] __ [ ]
 SMOKELESS         => SMOKE LESS       / [ ] __ [ ]
 SOMEHOW           => SOME HOW         / [ ] __ [ ]
 SOMEPLACE         => SOME PLACE       / [ ] __ [ ]
 SOMETIME          => SOME TIME        / [ ] __ [ ]
 SOMEDAY           => SOME DAY         / [ ] __ [ ]
 SOUTHEASTERN      => SOUTH EASTERN    / [ ] __ [ ]
 SOUTHWEST         => SOUTH WEST       / [ ] __ [ ]
 SPEEDWAY          => SPEED WAY        / [ ] __ [ ]
 SPINOFF           => SPIN OFF         / [ ] __ [ ]
 SPOTLIGHT         => SPOT LIGHT       / [ ] __ [ ]
 STANDOFF          => STAND OFF        / [ ] __ [ ]
 STATEWIDE         => STATE WIDE       / [ ] __ [ ]
 STOCKBROKER       => STOCK BROKER     / [ ] __ [ ]
 STOCKHOLDERS      => STOCK HOLDERS    / [ ] __ [ ]
 STRIKEOUT         => STRIKE OUT       / [ ] __ [ ]
 SUCHI             => SU CHI           / [ ] __ [ ]
 SUBCOMMITTEE      => SUB COMMITTEE    / [ ] __ [ ]
 SUBSTANDARD       => SUB STANDARD     / [ ] __ [ ]
 SUITCASES         => SUIT CASES       / [ ] __ [ ]
 SUMMERTIME        => SUMMER TIME      / [ ] __ [ ]
 SUPERBOWL         => SUPER BOWL       / [ ] __ [ ]
 SUPERSONICS       => SUPER SONICS     / [ ] __ [ ]
 SWEATSHOP         => SWEAT SHOP       / [ ] __ [ ]
 TAILHOOK          => TAIL HOOK        / [ ] __ [ ]
 TAKEOVER          => TAKE OVER        / [ ] __ [ ]
 TAKEOVERS         => TAKE OVERS       / [ ] __ [ ]
 TAXPAYER          => TAX PAYER        / [ ] __ [ ]
 TAXPAYERS         => TAX PAYERS       / [ ] __ [ ]
 THUNDERSTORM      => THUNDER STORM    / [ ] __ [ ]
 THUNDERSTORMS     => THUNDER STORMS   / [ ] __ [ ]
 TRAVELGATE        => TRAVEL GATE      / [ ] __ [ ]
 TURNOUT           => TURN OUT         / [ ] __ [ ]
;; valid-word typo  UNLESS            => UN LESS          / [ ] __ [ ]
 UPSIDE            => UP SIDE          / [ ] __ [ ]
 UPSTATE           => UP STATE         / [ ] __ [ ]
 VALUJET           => VALU JET         / [ ] __ [ ]
 VALUEJET          => VALU JET         / [ ] __ [ ]
 VIDEOTAPE         => VIDEO TAPE       / [ ] __ [ ]
 VIDEOTAPED        => VIDEO TAPED      / [ ] __ [ ]
 VIETNAM           => VIET NAM         / [ ] __ [ ]
 WALMART           => WAL MART         / [ ] __ [ ]
 WALLSTREET        => WALL STREET      / [ ] __ [ ]
 WARSHIP           => WAR SHIP         / [ ] __ [ ]
 WARTIME           => WAR TIME         / [ ] __ [ ]
 WASTEWATER        => WASTE WATER      / [ ] __ [ ]
 WATCHDOG          => WATCH DOG        / [ ] __ [ ]
 WHATEVER          => WHAT EVER        / [ ] __ [ ]
 WHITEWATER        => WHITE WATER      / [ ] __ [ ]
 WHOEVER           => WHO EVER         / [ ] __ [ ]
 WIDESPREAD        => WIDE SPREAD      / [ ] __ [ ]
 WILDFIRE          => WILD FIRE        / [ ] __ [ ]
 WILDFIRES         => WILD FIRES       / [ ] __ [ ]
 WILDLIFE          => WILD LIFE        / [ ] __ [ ]
 WITHOUT           => WITH OUT         / [ ] __ [ ]
 WOODCHIPS         => WOOD CHIPS       / [ ] __ [ ]
 WORKFORCE         => WORK FORCE       / [ ] __ [ ]
 WORKPLACE         => WORK PLACE       / [ ] __ [ ]
 WORLDWIDE         => WORLD WIDE       / [ ] __ [ ]
 WRONGDOING        => WRONG DOING      / [ ] __ [ ]
;; Additional Training Errors:
;; The correct orthography is a single word, but the training data is misleading
 AFTERALL          => AFTER ALL        / [ ] __ [ ]
 ALONGSIDE         => ALONG SIDE       / [ ] __ [ ]
 AUTOMAKER         => AUTO MAKER       / [ ] __ [ ]
 AUTOWORKERS       => AUTO WORKERS     / [ ] __ [ ]
 BACKDOOR          => BACK DOOR        / [ ] __ [ ]
 BACKSIDE          => BACK SIDE        / [ ] __ [ ]
 CLEANUP           => CLEAN UP         / [ ] __ [ ]
 LANDFALL          => LAND FALL        / [ ] __ [ ]
 LAYOFF            => LAY OFF          / [ ] __ [ ]
 LETDOWN           => LET DOWN         / [ ] __ [ ]
 MIDAIR            => MID AIR          / [ ] __ [ ]
 MULTINATIONAL     => MULTI NATIONAL   / [ ] __ [ ]
 NONUNION          => NON UNION        / [ ] __ [ ]
 PICKUP            => PICK UP          / [ ] __ [ ]
 PULLBACK          => PULL BACK        / [ ] __ [ ]
 SHAKEUP           => SHAKE UP         / [ ] __ [ ]
 SHUTOUT           => SHUT OUT         / [ ] __ [ ]
 SIDELINES         => SIDE LINES       / [ ] __ [ ]
 SURFBOARD         => SURF BOARD       / [ ] __ [ ]
 THUNDERSHOWER     => THUNDER SHOWER   / [ ] __ [ ]
 WALKOUT           => WALK OUT         / [ ] __ [ ]

;; others:
`                  => '
;;A                  => A.               / [ ] __ [ ] ;; "This is A B. C. News Nightline" (a960604)
;; also "on page A " (i960531)
;; NOT USED BECAUSE THIS IS A VIOLATION OF TRANSCRIPTION FORMATTING
ADMINISTATION      => ADMINISTRATION   / [ ] __ [ ]
;; valid-word typo AFFECT             => EFFECT           / [ ] __ [ ] ;; (b960611b)
AFFIMATIVE         => AFFIRMATIVE      / [ ] __ [ ]
AFORETHOUGHT       => OF FORETHOUGHT   / [ ] __ [ ] ;; with malice __ murdered (b960619)
;;of forethought     => aforethought ;; with malice __ murdered (b960619)
ALARMOUS           => ALARMIST         / [ ] __ [ ] ;; (n960715p)
;; valid-word typo ALEXANDER          => ALEXANDRE        / [ ] __ [ ] ;; Belgian Alexandre de Merode, of the Olympics 
;; valid-word typo AND                => IN               / [ ] __ [ ] ;; "america in black __ white tonight" (c960521)
;; should be in => and, but in already is confused with "is"!!
ARKANASAS          => ARKANSAS         / [ ] __ [ ]
;; valid-word typo ASTRO'S            => ASTROS           / [ ] __ [ ] ;; (f960603b)
BARABARA           => BARBARA          / [ ] __ [ ]
BAZAARE            => BIZAARE          / [ ] __ [ ] ;; (l960710)
;; valid-word typo BILLS              => BILL'S           / [ ] __ [ ] ;; (d960515)
BIS                => BIZ              / [ ] __ [ ] ;; short for "business"
BOARDWALK          => BOARD WALK       / [ ] __ [ ] ;; 1 word per AHD (d960530b)
;; board walk         => boardwalk ;; 1 word per AHD (d960530b)
BOB_MONDALLO       => BOB MONDELLO     / [ ] __ [ ] ;; Bob __, prominent movie critic; ALSO SPKRID!
BODAVICKA          => BARVIKHA         / [ ] __ [ ] ;; Yeltsin's health spa outside Moscow
;; valid-word typo BON                => BOB              / [ ] __ [ ] ;; Bob Dole (d960515)
BONDAR             => BANDAR           / [ ] __ [ ] ;; Saudi Prince Bandar Bin Sultan Bin Adbul Aziz (a960625)
;; valid-word typo BONDS'             => BONDS            / [ ] __ [ ] ;; (b960529)
BOYNAVICH          => VOINOVICH        / [ ] __ [ ] ;; Governor of Ohio
CHAIRNAMIRDEN      => CHERNOMYRDIN     / [ ] __ [ ] ;; Victor Chernomyrdin, Russian Prime Minister
CHECHIANS          => CHECHNYANS       / [ ] __ [ ]
CHECHNAYA          => CHECHNYA         / [ ] __ [ ]
CHILDRENS'         => CHILDREN'S       / [ ] __ [ ] ;; (c960517)
CHRISTIANNE        => CHRISTIANE       / [ ] __ [ ] ;; Christiane Amanpour, CNN reporter
CISCENEROS         => CISNEROS         / [ ] __ [ ] ;; Henry __, HUD Secretary
;; valid-word typo CLASS              => KLAAS            / [ ] __ [ ]
CLIFFHANGER        => CLIFF HANGER     / [ ] __ [ ] ;; 1 word per AHD
;;cliff hanger       => cliffhanger ;; 1 word per AHD
COCKRAN            => COCHRAN          / [ ] __ [ ] ;; Senator Thad __ (d960515)
COCKTAILING        => COCKTAIL N       / [ ] __ [ ] ;; (o960710p)
COULDV'E           => COULD'VE         / [ ] __ [ ] ;; (p960712)
COUSELLING         => COUNSELING       / [ ] __ [ ] ;; "a drugs __ service" (p960712)
CYNTHIA_ENGLE      => CYNTHIA ENGLE    / [ ] __ [ ]
DASHELL            => DASCHLE          / [ ] __ [ ] ;; Senator Thomas A. Daschle (d960515)
;; valid-word typo DAVIS              => DAVIS'           / [ ] __ [ ] ;; (b960619a)
DELAUREL           => DELAURO          / [ ] __ [ ] ;; Congresswoman Rosa DeLauro (d960515)
DEMORODE           => DE MERODE        / [ ] __ [ ] ;; Belgian Alexander de Merode, of the Olympics (bad spkrid)
DOAST              => COAST            / [ ] __ [ ] ;; West African __ (d960515)
DOLES'S            => DOLE'S           / [ ] __ [ ] ;; (j960524c)
DORMAN             => DORNAN           / [ ] __ [ ] ;; Congressman Robert K. Dornan (d960515)
ELECOTRAL          => ELECTORAL        / [ ] __ [ ] ;; (i960711p)
ELLENPORE          => AMANPOUR         / [ ] __ [ ] ;; Christiane __, CNN reporter
ELLEN PORE         => AMANPOUR         / [ ] __ [ ] ;; Christiane __, CNN reporter
;; valid-word typo EMBOLDEN           => EMBOLDENED       / [ ] __ [ ] ;; a960528
ETC.               => ET CETERA        / [ ] __ [ ]
;; valid-word typo FEELS              => FEARS            / [ ] __ [ ] ;; She __ it will only (j960522b)
FUNDERBERK         => FUNDERBURK       / [ ] __ [ ] ;; Hon. David __ (k960712)
;; valid-word typo GAIL => GALE / [ ] __ [ ] ;; Porter Gale, member of 2 Chicks, 2 Bikes, 1 Cause (d960515)
GALUDET            => GALLAUDET        / [ ] __ [ ] ;; University
;;GENE               => JIM              / [ ] __ [ ] ;; Jim Randle, former editor for CNN Washington
;; no, in d960515 @4025  and 4146, they clearly say "Gene" -- including Gene himself!
GOVENOR            => GOVERNOR         / [ ] __ [ ] ;; (j960520)
;; valid-word typo GRIFFEY'S          => GRIFFEYS         / [ ] __ [ ] ;; (b960529)
HAMHANDED          => HAM HANDED       / [ ] __ [ ] ;; 1 word per AHD!
;; valid-word typo HAS                => WILL HAVE        / [ ] __ [ ] ;; "Jean Randall __ more on that story" (d960515,~3690)
;; valid-word typo HASSAN             => HASAN            / [ ] __ [ ] ;; Hasan Muratovic, P.M of Bosnia
HERNAN             => HERNDON          / [ ] __ [ ] ;; town in VA (BUT CHECK OUT i960604)
;; valid-word typo HOW                => WHO'S            / [ ] __ [ ] ;; "I'm someone __ spent a long time in" (f960603b)
;; valid-word typo IN                 => IS               / [ ] __ [ ] ;; "war against drugs __ under way" (p960712)
;; valid-word typo INNOCENSE          => INNOCENTS        / [ ] __ [ ] ;; (p960712)
;; valid-word typo INSIST             => INSISTS          / [ ] __ [ ] ;; "Roland Dickey __ that beef is better" (f960613)
INTERM             => INTERIM          / [ ] __ [ ] ;; "a lot of ah __ steps that could" (j960520c)
;; valid-word typo IS                 => IT'S             / [ ] __ [ ] ;; that means it's __ denied (b960620a)
;; valid-word typo ISRAELIS           => ISRAELIS'        / [ ] __ [ ] ;; (?) the major __ opinion in Israel (b960529)
ISUDEAN            => IZUDIN           / [ ] __ [ ] ;; Izudin Kapetanovic, prime minister of Bosnia+Herz.
;; valid-word typo IT'S               => ITS              / [ ] __ [ ] ;; the I. R. A. renews it's cease fire (b960611b)
;; also "these problems it's found" (j960520c)
;; valid-word typo THE SAME           => IT'S SAYING A    / [ ] __ [ ] ;; (d960515)
;; it's saying a      => THE SAME ;; (d960515)
;;JEAN               => JIM              / [ ] __ [ ] ;; Jim Randle, former editor for CNN Washington (d960515)
;; valid-word typo JEAN               => GENE              / [ ] __ [ ] ;; Jim Randle, former editor for CNN Washington (d960515)
;; let's say his name is GENE, since he's clearly called that at several other places in d960515
;; valid-word typo JEANNE             => JANINE           / [ ] __ [ ] ;; CNN reporter __ Shirell (d960515)
;; valid-word typo JOHN               => JON              / [ ] __ [ ] ;; Senator Jon Kyle
KABART             => KHOBAR           / [ ] __ [ ] ;; Al __, Saudi bombing site (a960625)
;; KACZYNSKI          => KACZYNSKI'S      / [ ] __ [ ] ;; found in Theodore __ Montana cabin (d960515)
KAPTONOVITCH       => KAPETANOVIC      / [ ] __ [ ] ;; Izudin Kapetanovic, P.M. of Bosnia+Herz.
KARADICH           => KARADZIC          / [ ] __ [ ] ;; Radovan __
KARADIC            => KARADZIC          / [ ] __ [ ] ;; Radovan __
KARADZICH          => KARADZIC          / [ ] __ [ ] ;; Radovan __
;; Infoseek hits on Net:
;; Karadzic  5547
;; Karadic     44
;; Karadzich   11
;; Karadich     1
;; valid-word typo KLINGER            => CLINGER          / [ ] __ [ ] ;; Congressman William Clinger Jr.
KOBAR              => KHOBAR           / [ ] __ [ ] ;; Al __, Saudi bombing site (i960711p)
LALLO              => LALO             / [ ] __ [ ] ;; composer __ Schifrin, nominated for Oscar in 1980
;; valid-word typo LATINO'S           => LATINOS          / [ ] __ [ ] ;; blacks and ___ (o960710p)
;; valid-word typo LETS               => LET'S            / [ ] __ [ ] ;; d960515
LEWENSKY           => LEWINSKI         / [ ] __ [ ] ;; George __, of the NPR
LIESIN             => LIESON           / [ ] __ [ ] ;; Mara __, NPR reporter
;; valid-word typo LOT                => LOTT             / [ ] __ [ ] ;; Senator Trent Lott (d960515)
MABIS              => MABUS            / [ ] __ [ ] ;; American Ambassador to Saudi Arabia Raymond __; bad id Ray_Madis
MADIS              => MABUS            / [ ] __ [ ] ;; American Ambassador to Saudi Arabia Raymond __; bad id Ray_Madis
MALOTITCH          => MLADIC           / [ ] __ [ ] ;; Ratko __
MARADOVITCH        => MURATOVIC        / [ ] __ [ ] ;; Hasan Muratovic, P.M of Bosnia
;; valid-word typo MARSHALLS          => MARGINS          / [ ] __ [ ] ;; pile up winning ___ (d960530b)
MARTIALS           => MARSHALS         / [ ] __ [ ] ;; Federal __
MIANMAR            => MYANMAR          / [ ] __ [ ] ;; formerly Burma
MIDWEST            => MID WEST         / [ ] __ [ ] ;; 1 word per AHD
;; mid west           => Midwest ;; 1 word per AHD
;; Mid-west           => Midwest ;; 1 word per AHD
MILADIC            => MLADIC           / [ ] __ [ ] ;; Ratko __
MILODIC            => MLADIC           / [ ] __ [ ] ;; Ratko __
MLADICH            => MLADIC           / [ ] __ [ ] ;; Ratko __
MONDALLO           => MONDELLO         / [ ] __ [ ] ;; Bob __, prominent movie critic
;; valid-word typo MUNCEE             => MUNCIE           / [ ] __ [ ] ;; town in Indiana
;; valid-word typo MURDERED           => MURDER           / [ ] __ [ ] ;; with malice of forethought ___ (b960619)
NETANYAHU          => NETAN YAHU       / [ ] __ [ ]
;; Netan Yahu         => Netanyahu
NICHOLIECH         => NIKOLAEVICH      / [ ] __ [ ] ;; Yeltsin's patronymic
NICHOLIECH'S       => NIKOLAEVICH'S    / [ ] __ [ ] ;; Yeltsin's patronymic
;; valid-word typo NICKELS            => NICKLES          / [ ] __ [ ] ;; Senator Don Nickles
;; valid-word typo NON                => NOT              / [ ] __ [ ] ;; "a non so easily recovering alcoholic" (j960522b)
;; valid-word typo NOW                => KNOW             / [ ] __ [ ] ;; "you __ many times" (j960522d)
OCCURED            => OCCURRED         / [ ] __ [ ]
OKAY               =>  O. K.           / [ ] __ [ ]
;;o. k.              => okay 
;; these next two should be used only in scoring, not as an indication
;; of which transcription is correct; in fact, "or" and "um" are correct.
;; valid-word typo OF                 => OR               / [ ] __ [ ] ;; a960625, "either Afghanistan of Bosnia", found w/LM
OVERBUDGET         => OVER BUDGET      / [ ] __ [ ]
;; valid-word typo OWN                => ON               / [ ] __ [ ] ;; it's __ deep south accent (b960620a)
PAIGN              => PAYNE            / [ ] __ [ ] ;; Billy Payne, organizer of Atlanta Olympics
PARACUTE           => PARACHUTE        / [ ] __ [ ]
PARY               => PARTY            / [ ] __ [ ] ;; Labor __
;; valid-word typo PAYERS             => PAYERS'          / [ ] __ [ ] ;; tax payers money" (k960607)
;; valid-word typo PEOPLES            => PEOPLE'S         / [ ] __ [ ] ;; "peoples lives" (c960516)
PEREZ              => PERES            / [ ] __ [ ] ;; Shimon __, Israeli
PEROSKI            => PIROZHKI         / [ ] __ [ ]
PHILIDELPHIA       => PHILADELPHIA     / [ ] __ [ ] ;; (o960710p)
POLY               => POLLY            / [ ] __ [ ] ;; __ Klaas
POLY CLASS         => POLLY KLAAS      / [ ] __ [ ]
POTBOILER          => POT BOILER       / [ ] __ [ ] ;; 1 word per AHD
;;pot boiler         => potboiler ;; 1 word per AHD
;;pot-boiler         => potboiler ;; 1 word per AHD
PRETEEN            => PRE TEEN         / [ ] __ [ ] ;; 1 word per AHD
;;pre teen           => preteen ;; 1 word per AHD
;;pre-teen           => preteen ;; 1 word per AHD
PRISONED           => PRISON           / [ ] __ [ ] ;; (b960619a)
PRODY              => PRODI            / [ ] __ [ ] ;; Italian prime minister)
RADAVAN            => RADOVAN          / [ ] __ [ ] ;; __Karadic
RADDITZ            => RADITZ           / [ ] __ [ ]
RADKO              => RATKO            / [ ] __ [ ] ;; __ Mladic
RANDEL             => RANDLE           / [ ] __ [ ] ;; Jim(?) Randle, former editor for CNN Washington
RANDELL            => RANDLE           / [ ] __ [ ] ;; Jim(?) Randle, former editor for CNN Washington
REKNOWNED          => RENOWNED         / [ ] __ [ ]
ROITERS            => REUTERS          / [ ] __ [ ]
ROL AND            => ROLAND           / [ ] __ [ ] ;; "__ Dickey insists that beef is better" (f960613)
ROOFIE             => ROOFY            / [ ] __ [ ] ;; rohypnol
ROTCKO             => RATKO            / [ ] __ [ ] ;; __ Mladic
ROUNDTABLE         => ROUND TABLE      / [ ] __ [ ] ;; 1 word per AHD
;;round table        => roundtable ;; 1 word per AHD
ROXBOROUGH         => ROXBOUROUGH      / [ ] __ [ ] ;; Angus, BBC reporter
RUPHY              => ROOFY            / [ ] __ [ ] ;; rohypnol
RUSED              => RUSHED           / [ ] __ [ ]
;; valid-word typo S                  => S-               / [ ] __ [ ] ;; subliminal or anything __ I'm not (o960710p)
SAMARACH           => SAMARANCH        / [ ] __ [ ] ;; Juan Antonio Samaranch, of the Olympics
SAMARACH'S         => SAMARANCH'S      / [ ] __ [ ] ;; Juan Antonio Samaranch, of the Olympics
SAMPRE             => SAMPER           / [ ] __ [ ] ;; Ernesto, president of Colombia
SANA               => SANTA            / [ ] __ [ ] ;; Santa Cruz Chili & Spice Co. (e960510a)
SANDOSE            => SANDOZ           / [ ] __ [ ]
SARI'S             => SARIS            / [ ] __ [ ]
SCHIFERON          => SCHIFRIN         / [ ] __ [ ] ;; composer Lalo __, nominated for Oscar in 1980
SCHMIDDY           => SMITHY           / [ ] __ [ ] ;; "Under the spreading chestnut tree, the village __"
;; "smithy" intentionally mispronounced "schmiddy"
SCOLIA             => SCALIA           / [ ] __ [ ] ;; Supreme Court Justice Antonin __
SCURDALL           => SKURDAL          / [ ] __ [ ] ;; the Freeman
SCURDELL           => SKURDAL          / [ ] __ [ ] ;; the Freeman
SE                 => SEE              / [ ] __ [ ] ;; (b960605a.txt)
SEAFRONT           => SEA FRONT        / [ ] __ [ ] ;; per AHD
SEBRADIZA          => SREBRENICA       / [ ] __ [ ]
SEBRINIDZA         => SREBRENICA       / [ ] __ [ ]
SEIGAL             => SIEGAL           / [ ] __ [ ]
;; valid-word typo SENDERS            => SENATORS         / [ ] __ [ ]
;; valid-word typo SEOUX              => SUE              / [ ] __ [ ] ;; "Seoul City ___" (?)
SERGAY             => SERGEI           / [ ] __ [ ] ;;Sergei Medvedev, Yeltsin's press secretary
SETBACK            => SET BACK         / [ ] __ [ ] ;; 1 word per AHD
;;set back           => setback ;; 1 word per AHD
SHAVARNIDZA        => SREBRENICA       / [ ] __ [ ] ;; (p960712)
SHEVARDNIDZA       => SREBRENICA       / [ ] __ [ ] ;; (p960712)
SHEVARNIDZA        => SREBRENICA       / [ ] __ [ ] ;; (p960712)
;; valid-word typo SHE                => SHE'S            / [ ] __ [ ] ;; And __ made some recent (j960522b)
SHIMONE            => SHIMON           / [ ] __ [ ] ;; __ Peres, Israeli
SHIRELL            => SHIRELLE         / [ ] __ [ ] ;; CNN reporter
SHIRONE            => SHARON           / [ ] __ [ ] ;; Ariel __, Israeli
;; valid-word typo SID                => CID              / [ ] __ [ ] ;; El __
;; valid-word typo SILVESTER          => SYLVESTER        / [ ] __ [ ] ;; __ Stallone
SIMILACK           => SIMILAC          / [ ] __ [ ]
SIMULAC            => SIMILAC          / [ ] __ [ ]
SINKPACK           => CINCPAC          / [ ] __ [ ]
SITCOME            => SITCOM           / [ ] __ [ ]
SKERDAL            => SKURDAL          / [ ] __ [ ] ;; the Freeman
SKYWAY             => SKY WAY          / [ ] __ [ ] ;; 1 word per AHD
;;sky way            => skyway ;; 1 word per AHD
SPONGEFORM         => SPONGIFORM       / [ ] __ [ ]
STANDOFF           => STAND OFF        / [ ] __ [ ] ;; 1 word per AHD
;;stand off          => standoff ;; 1 word per AHD
;;stand-off          => standoff ;; 1 word per AHD
STEINBERGEN        => STEENBURGEN      / [ ] __ [ ] ;; Mary __, the actress
STONEWALLING       => STONE WALLING    / [ ] __ [ ] ;; 1 word per AHD
;;stone walling      => stonewalling ;; 1 word per AHD
STRAUM             => STROM            / [ ] __ [ ] ;; Senator Strom Thurmond
STREEET            => STREET           / [ ] __ [ ] ;; (i960711p)
SUMATOMA           => SUMITOMO         / [ ] __ [ ]
;; valid-word typo T                  => T-               / [ ] __ [ ] ;; to get __ real zany (o960710p)
TAXANS             => TEXANS           / [ ] __ [ ] ;; (o960710p)
;; valid-word typo THE                => FOR              / [ ] __ [ ] ;; __ nearly two thousand Liberian (d960515)
;; valid-word typo THEODORE           => IN THEODORE      / [ ] __ [ ] ;; found __ Kaczynski's Montana cabin (d960515)
;;in Theodore        => Theodore  ;; found __ Kaczynski's Montana cabin (d960515)
;; valid-word typo THERE              => THEY'RE          / [ ] __ [ ] ;; for all the fun that there talking about (b960619b)
THURMAN            => THURMOND         / [ ] __ [ ] ;; Senator Strom Thurmond
TIELESS            => TIE LESS         / [ ] __ [ ] ;; "tie less" in g960516; "tieless doesn't occur) ????
;; valid-word typo TO IT              => TO WIT           / [ ] __ [ ] ;; felony __ a violation
;; valid-word typo TRIES              => TRIED            / [ ] __ [ ] ;; "even as firefighters ____ to control" (j960521d)
TUSCON             => TUCSON           / [ ] __ [ ] ;; (e960510a)
;; valid-word typo UM                 => OF               / [ ] __ [ ] ;; __ there are investigations (a960610)
;; should be of => um, but of => other things too
VALIA              => THALIA           / [ ] __ [ ] ;; Thalia Sures, ABC reporter
;; valid-word typo VALUE JET          => VALU JET         / [ ] __ [ ]
VISTON             => VINCENT          / [ ] __ [ ] ;; " __ Foster", in talk of White House politics (a960626)
;; Sen. Orrin Hatch actually mispronounced Vincent Foster's name as "Viston".
WASHINGTOAN        => WASHINGTON       / [ ] __ [ ] ;; (d960515)
;; valid-word typo WELL               => WE'LL            / [ ] __ [ ] ;; and __ prepare him (b960620a)
WILFULLY           => WILLFULLY        / [ ] __ [ ]
WYDE               => WYDEN            / [ ] __ [ ] ;; Senator Ron Wyden, Dem OR (i960604)
XOCHIMILCO         => SOTTI MILCO      / [ ] __ [ ]
;;Sotti Milco        => Xochimilco
;; valid-word typo YOUR               => YOU'RE           / [ ] __ [ ] ;; not if YOUR a mail carrier (b960613a)
;; end of training_errs.rls
;;
;;  Interjection Mappings
UH-HUH  =>  UHHUH     / [ ] __ [ ]
MHM     =>  UHHUH     / [ ] __ [ ]
MMHM    =>  UHHUH     / [ ] __ [ ]
MM-HM   =>  UHHUH     / [ ] __ [ ]
MM-HUH  =>  UHHUH     / [ ] __ [ ]
HUH-UH  =>  UHUH      / [ ] __ [ ]
;;
;;
UH      =>  %HESITATION     / [ ] __ [ ]
UM      =>  %HESITATION     / [ ] __ [ ]
EH      =>  %HESITATION     / [ ] __ [ ]
MM      =>  %HESITATION     / [ ] __ [ ]
HM      =>  %HESITATION     / [ ] __ [ ]
AH      =>  %HESITATION     / [ ] __ [ ]
HUH     =>  %HESITATION     / [ ] __ [ ]
HA      =>  %HESITATION     / [ ] __ [ ]
ER      =>  %HESITATION     / [ ] __ [ ]
OOF     =>  %HESITATION     / [ ] __ [ ]
HEE     =>  %HESITATION     / [ ] __ [ ]
ACH     =>  %HESITATION     / [ ] __ [ ]
EEE     =>  %HESITATION     / [ ] __ [ ]
EW      =>  %HESITATION     / [ ] __ [ ]
;;
%UH      =>  %HESITATION     / [ ] __ [ ]
%UM      =>  %HESITATION     / [ ] __ [ ]
%EH      =>  %HESITATION     / [ ] __ [ ]
%MM      =>  %HESITATION     / [ ] __ [ ]
%HM      =>  %HESITATION     / [ ] __ [ ]
%AH      =>  %HESITATION     / [ ] __ [ ]
%HUH     =>  %HESITATION     / [ ] __ [ ]
%HA      =>  %HESITATION     / [ ] __ [ ]
%ER      =>  %HESITATION     / [ ] __ [ ]
%OOF     =>  %HESITATION     / [ ] __ [ ]
%HEE     =>  %HESITATION     / [ ] __ [ ]
%ACH     =>  %HESITATION     / [ ] __ [ ]
%EEE     =>  %HESITATION     / [ ] __ [ ]
%EW      =>  %HESITATION     / [ ] __ [ ]
