#!/bin/sh -- # -*- perl -*- -w
eval 'exec perl -S $0 ${1+"$@"}'
    if 0;

##### Version history
##
##  0.1 - initial release
##
##  0.2 - December 8, 1998
##      - Added the -c and -p options
##      - Added another rule to the merge portion of the script to handle
##        inter-word begin NE tags
##      - Corrected the handling of the <HYPHEN> tags
##        
##

$Version = "0.2";

$usage="IdF_utf_wrapper.pl [ -c -p pid ] -I IdentiFinder_ROOT -i input_utf -o output_tagged_utf\n".
"Version: $Version\n".
"Desc:  This script calls the BBN IdentiFinder Program on and input UTF file\n".
"       and outputs a named-entity tagged UTF file, suitable for scoring through\n".
"       SAIC's MUC scorer for ASR technology\n".
"\n".
"       The -I option identifies the root directory of the BBN IdentiFinder tagger\n".
"       See the accompanying documentation for acquisition instructions.  The input\n".
"       UTF file is specified by the -i option, and the tagged UTF is written to the\n".
"       file specified by the -o option.\n".
"Options:\n".
"   -c       Do not delete temporary files\n".
"   -p PID   Use the string 'PID' in the temporary file names. This is for debugging\n".
"\n";

$PID=$$;
require "getopts.pl";
&Getopts('ci:o:I:p:');
die("$usage\n\nError: both -i, -I and -o required") 
    if(!defined($opt_i) || !defined($opt_o) || !defined($opt_I));

$inf = $opt_i;
$outf = $opt_o;
$IDFROOT = $opt_I;
if (defined($opt_c)) { $CleanUp = !$opt_c; } else { $CleanUp = 1; }
if (defined($opt_p)) { $PID = $opt_p; }

$TMPDIR = ".";
$TMP="${TMPDIR}/IdF.utf.$PID";

####

####

print "IdF_utf_wrapper.pl: reformatting the input utf (${TMP}.wtag)\n";
if (-f "${TMP}.wtag"){
    print "                    .... ${TMP}.wtag already created, delete to rebuild\n";
} else {
    open(IN,"<$inf") || die("Can not open input file $inf");
    open(TMP,">${TMP}.wtag") || die("Can not open temp file ${TMP}.wtag");

    local($inturn) = 0;
    while(<IN>){
	if ($_ =~ /<TURN/i){
	    print TMP $_."<TEXT>\n<s>\n"; 
	    $inturn = 1;
	    if ($_ =~ /<TURN.*starttime=(\S+)/i){
		$lt = $1;
	    }
	} elsif ($_ =~ /<\/TURN/i){
	    print TMP "\n<\s>\n</TEXT>\n".$_; 
	    $inturn = 0;	    
	} else { 
	    ## Convert acronyms
	    s/>_(\S)/>$1./;
	    # convert hyphen tags
	    s/<hyphen>/ <hyphen> /gi;
	    if ($inturn) { 
		foreach $it(1 .. 6) { s/([\s>][^<]*)_([^_])/$1 $2. /g }
		$it = "";
		tr/a-z/A-Z/;
		s/\s(\S)\./ _$1/g;
	    }		
	    if ($_ =~ /<WTIME.*starttime=(\S+)/i){
		$tt = $1;
		if ($tt - $lt > 0.5){ print TMP "\n</s>\n<s>\n"; }
		if ($_ =~ /<WTIME.*endtime=([^\s>]+)/i){
		    $lt = $1;
		}
	    }
	    # delete nonlexemes
	    s/%\S+//gi;
	    # delete fragments
	    s/\s\S+<fragment>//gi;
	    
	    chop;
	    print TMP $_." " ;
	}
    }
    close (TMP);
    close(IN);
}

print "IdF_utf_wrapper.pl: Generating the utf without wtime (${TMP}.notag)\n";
if (-f "${TMP}.notag"){
    print "                    .... ${TMP}.notag already created, delete to rebuild\n";
} else {
    open(TMP,"<${TMP}.wtag") || die("Can not open temp file ${TMP}.wtag");
    open(NOT,">${TMP}.notag") || die("Can not open temp file ${TMP}.notag");
    while(<TMP>){
	$_ =~ s/<wtime[^>]*>//gi;
	$_ =~ s/<time[^>]*>//gi;
	$_ =~ s/<hyphen>//gi;
	print NOT $_;
    }
    close(TMP); close(NOT);
    
}

print "IdF_utf_wrapper.pl: Calling IndentiFinder, (${TMP}.notag.ne)\n";
if (-f "${TMP}.notag.ne"){
    print "                    .... ${TMP}.notag.ne already created, delete to rebuild\n";
} else {
    $success=0;
    $lnd="$IDFROOT/data";
    $com="LNE_DATA_DIR=$lnd; export LNE_DATA_DIR; $IDFROOT/bin.english.sun4sol/test-ne-decoder -file $lnd/lne-english-params -odir ${TMPDIR} ${TMP}.notag";
    
    open(LOG,"$com 2>&1 |") || die("Unable to start IndentiFinder");
    while(<LOG>){ $success = 1 if ($_ =~ /Done decoding/); push(@log,$_); }
    close(LOG);
    die("IndentiFinder Failed: ".join("",@log)) if ($success == 0);
}

print "IdF_utf_wrapper.pl: Putting the tagged data back together\n";

$dbg = 0;
open(WTAG,"${TMP}.wtag") || die("Can not open ${TMP}.wtag");
open(NETAG,"${TMP}.notag.ne") || die("Can not open ${TMP}.notag.ne");
open(MERGED,">$outf") || die("Can not open output file $outf");
while(<WTAG>){
    $str = "";
    $wtag = $_;
    $wtag =~ s/(<wtime[^>]*>)/$1 /gi;

    $netag = <NETAG>;
    $netag =~ s/(<(enam|tim|num)ex[^>]*>)/$1 /gi;
    $netag =~ s/(<\/(enam|tim|num)ex>)/ $1/gi;

    ### netag should only have insertions
    @wt = split(/\s+/,$wtag);
    @ne = split(/\s+/,$netag);
    ### Loop through tokens
    while ($#wt >= 0 && $#ne >= 0){
	print "Begin: .$wt[0]. .$ne[0].\n" if ($dbg);
	if ($wt[0] eq $ne[0]){
	    print "    Rule 1:\n" if ($dbg);   
	    $str .= "$wt[0] ";
	    splice(@wt,0,1);
	    splice(@ne,0,1);
	} elsif ($ne[0] =~ /^<*(ena|ti|nu)mex/i){
	    print "    Rule 2:\n" if ($dbg);   
	    while ($ne[0] !~ /<\/*(ena|ti|nu)mex[^>]*>/i) {
		$ne[0] .= " ".splice(@ne,1,1);
	    }
	    $str .= "$ne[0] ";
	    splice(@ne,0,1);	    
	} elsif ($ne[0] =~ /([^\s<]+)<*(ena|ti|nu)mex/i){
	    $pretext = $1;
	    print "    Rule 2a:\n" if ($dbg);   
	    while ($ne[0] !~ /<\/*(ena|ti|nu)mex[^>]*>/i) {
		$ne[0] .= " ".splice(@ne,1,1);
	    }
	    $str .= "$ne[0] ";
	    splice(@ne,0,1);	 
	    $wt[0] =~ s/^$pretext//i;
	} elsif ($wt[0] =~ /<wtime/i){
	    print "    Rule 3:\n" if ($dbg);   
	    while ($wt[0] !~ /<wtime[^>]*>/i) {
		$wt[0] .= " ".splice(@wt,1,1);
	    }
	    $str .= "$wt[0] ";
	    splice(@wt,0,1);	    
	} elsif ($wt[0] =~ /<time/i){
	    print "    Rule 4:\n" if ($dbg);   
	    while ($wt[0] !~ /<time[^>]*>/i) {
		$wt[0] .= " ".splice(@wt,1,1);
	    }
	    $str .= "$wt[0] ";
	    splice(@wt,0,1);	    
	} elsif ($wt[0] =~ /<hyphen/i){
	    print "    Rule 5:\n" if ($dbg);   
	    while ($wt[0] !~ /<hyphen>/i) {
		$wt[0] .= " ".splice(@wt,1,1);
	    }
	    $str .= "$wt[0] ";
	    splice(@wt,0,1);	    
	} elsif ($ne[0] =~ /<\/(ena|ti|nu)mex/i){
	    print "    Rule 6:\n" if ($dbg);   
	    while ($ne[0] !~ /<\/*(ena|ti|nu)mex[^>]*>/i) {
		$ne[0] .= " ".splice(@ne,1,1);
	    }
	    $str .= "$ne[0] ";
	    splice(@ne,0,1);	    
	} elsif ($ne[0] !~ /<\/*(ena|ti|nu)mex/i && $wt[0] !~ /<wtime/){
	    print "    Rule 7:\n" if ($dbg);   
	    ### Damn contractions
	    ($net = $ne[0].$ne[1]) =~ s/<[^>]*>//;
	    if ($wt[0] ne $net){
		print "\n\nContraction fix failed\nwt=".join(" ",@wt).
		    "\n--------------\nne=".
			join(" ",@ne)."\n";;
		die;
	    }
	    $str .= "$ne[0]$ne[1] ";
	    splice(@wt,0,1);
	    splice(@ne,0,2);
	} else {
	    print "\n\nConfusion\nwt=".join(" ",@wt)."\n--------------\nne=".
		 join(" ",@ne)."\n";;
	    die;
	}
    }
    while ($#ne >= 0){
	$str .= " ".splice(@ne,0,1);
    }
    while ($#wt >= 0){
	$str .= " ".splice(@wt,0,1);
    }
    $str =~ s:(<(ena|ti|nu)mex[^>]*>)\s+:$1:gi;
    $str =~ s:(<wtime[^>]*>)\s+:$1:gi;
    $str =~ s:\s+(</(ena|ti|nu)mex>):$1:gi;
    ## Convert acronyms
    $str =~ s/>(\S)\./>_$1/g;
    ## Fix hyphen tags
    $str =~ s/\s*(<hyphen>)\s*/$1/gi;
    

    $str =~ s/<(enamex|timex|numex)/<b_$1/gi;
    $str =~ s/<\/(enamex|timex|numex)/<e_$1/gi;

    ## Print it nicely
    $str =~ s/\s(<B_(ENAMEX|TIMEX|NUMEX)|<WTIM)/\n$1/gi;

    print MERGED "$str\n" if ($str !~ /<\/*(text|s)>/i);
}
close(WTAG);
close(NETAG);
close(MERGED);

### Clean-up

print "IdF_utf_wrapper.pl: Cleaning up!\n";
foreach $file("${TMP}.wtag", "${TMP}.notag", "${TMP}.notag.ne"){
    if ($CleanUp){
	system "rm -f $file";
    } else {
	print "   Not Removing $file\n";
    }
}



