#!/bin/sh -- # -*- perl -*- -w
eval 'exec perl -S $0 ${1+"$@"}'
    if 0;

$Version = "0.2";

$Usage = "Usage:  ctm2utf.pl -a audio_filename < CTMFILE > UTFFILE\n".
"Version: $Version\n".
"Desc: This script reads a CTM file and reformats it into UTF format.\n".
"      The script reads STDIN and writes to STDOUT.  An audio filename,\n".
"      (without filename extensions), is required using the -a argument.\n".
"Arguments:\n".
"    -a filename   The SPHERE file filename from which this data was generated.\n".
"                  There should be no extensions on the filename.\n".
"    -h            Produce this message and exit.\n";

require "getopts.pl";
&Getopts('ha:');

if (defined($opt_h)){ print $Usage; exit $opt_h; }
if (defined($opt_a)){
    $AUDFILE=$opt_a;
} else {
    die "$Usage\n\nError, I need the audio filename to generate proper output\n";
}


#### Reads CTM from stdin and writes to stdout

$firstline = 1;

while(<STDIN>){
    next if ($_ =~ /^;;/);
    s/^\s+//;
    push(@a, [ split ] );
    if ($firstline){
	$firstline = 0;	
	print "<utf dtd_version=utf-1.0 audio_filename=$AUDFILE language=UNK scribe=UNK version=1 version_date=UNK>\n";
	print "<bn_episode_trans program=UNK air_date=UNK>\n";
	print "<!-- Generated by ctm2utl.pl version $Version -->\n";
    }
    if ($#a > 1){
	if ($a[0][0] ne $a[$#a][0]){
	    &process_file(0,$#a-1);
	}
    }
}
if ($#a >= 0) { &process_file(0,$#a); }

print "</bn_episode_trans>\n";
print "</utf>\n";

exit 0;

sub process_file{
    local($begid, $endid) = @_;
    local($mint, $maxt) = (9999999, -99999);
    local($i);

    for ($i=$begid; $i<=$endid; $i++){
	$mint = $a[$i][2] if ($mint > $a[$i][2]);
	$maxt = $a[$i][2]+$a[$i][3] if ($maxt < $a[$i][2] + $a[$i][3]);
    }
    print "<section type=filler startTime=$mint endTime=$maxt id=$a[$begid][0]>\n";
    
    ### find the turn sets
    local($chanbeg, $chanend) = ($begid, $begid);
    while ($chanbeg <= $endid){
	for (; $chanend < $endid && $a[$chanend][1] eq $a[$chanend+1][1]; $chanend++){ ; } 
	&process_chan($chanbeg,$chanend);
	$chanbeg = ++$chanend;
    }

    print "</section>\n";
    splice(@a,$begid,$endid-$begid+1);
}

sub process_chan{
    local($begid, $endid) = @_;
    local($mint, $maxt) = (9999999, -99999);
    local($i);

    for ($i=$begid; $i<=$endid; $i++){
	$mint = $a[$i][2] if ($mint > $a[$i][2]);
	$maxt = $a[$i][2]+$a[$i][3] if ($maxt < $a[$i][2] + $a[$i][3]);
    }
    print "<turn channel=$a[$begid][1] startTime=$mint endTime=$maxt speaker=$a[$begid][0]_$a[$begid][1] spkrtype=unknown>\n";

    for ($i=$begid; $i<=$endid; $i++){
        # number of space-separated chunks in a[i]:
        my $n = (scalar @{$a[$i]}) - 1;

        # The word(s) after the numbers
        my $wan = join(" ",@{$a[$i]}[4..$n]);
	
	# Converter mr. mrs, and ms.
	$wan =~ s/MR\./MISTER/gi;
	$wan =~ s/MRS\./MRS/gi;
	$wan =~ s/MS\./MS/gi;

	### Handle abbreviations
	# $a[$i][4] =~ s/^(\S+)\.$/_$1/;	
	# $a[$i][4] =~ s/^(\S+)\.('\S+)$/_$1$2/;  

	$wan =~ s/(\w+)\./_$1/g;	
	$wan =~ s/(\w+)\.('\w+)/_$1$2/g;  

        $wan =~ s/<ENAMEX/<B_ENAMEX/ig;
        $wan =~ s/<\/ENAMEX/<E_ENAMEX/ig;
        $wan =~ s/<TIMEX/<B_TIMEX/ig;
        $wan =~ s/<\/TIMEX/<E_TIMEX/ig;
        $wan =~ s/<NUMEX/<B_NUMEX/ig;
        $wan =~ s/<\/NUMEX/<E_NUMEX/ig;

	# printf "<wtime startTime=$a[$i][2] endTime=%.2f>$a[$i][4]\n", $a[$i][2] + $a[$i][3] ;
	printf "<wtime startTime=$a[$i][2] endTime=%.2f>%s\n",$a[$i][2]+$a[$i][3],$wan;
    }
    
    print "</turn>\n";
}



