#!/bin/sh -- # -*- perl -*- -w
eval 'exec perl -S $0 ${1+"$@"}'
    if 0;

$Version="1";
########################################################
# File: utf2nerf.pl
#
# History:
#
#  Version 1
#
#
########################################################


########################################################
# constant definitions
########################################################

# debug level
#
#$DEBUG_NONE = 0;
$DEBUG_BRIEF = 1;
#$DEBUG_DETAIL = 2;
#$DEBUG_FULL = 4;

# define usage statement
#
$USAGE = "\n\n$0 -e <dtd file> -i <input file> -o <output file>\n\n".
"Version: $Version\n".
"Desc:  This script reformats an input UTF transcript file to the form used as\n".
"       a IE-NE reference transcript for tagging\n"."\n".
"Required arguments:\n".
"   -e <dtd file> is the dtd file\n".
"   -i <input file>  is the sgml transcript\n".
"   -o <output file> is the output of this script\n".
"\n";


########################################################
# global variables
########################################################

$conformance = 0;
$input = "";
$output = ""; 
$dtd_file = "";
${DBoff}="";
$debug_level=0;
$lc_newline=1;
$lc_separator=0;
$skip_to_separator=0;

########################################################
# include extended perl libraries
########################################################

# use the SGMLS class
#
use SGMLS;

########################################################
# main program
########################################################

require "getopts.pl";
&Getopts('e:i:o:');

# Checking
#
die "$USAGE\n\nError: Output file '-o' req'd" if (!defined($opt_o));
die "$USAGE\n\nError: Input file '-i' req'd" if (!defined($opt_i));
die "$USAGE\n\nError: DTD file '-e' req'd" if (!defined($opt_e));

die "Error: DTD file '$opt_e' is not a readable file" if (! -r $opt_e);
die "Error: Input file '$opt_i' is not a readable file" if (! -r $opt_i);

# Assignments
#
$input = $opt_i;
$dtd_file = $opt_e;
$output = $opt_o;


# open files
#
open(IN, "cat $dtd_file $input | nsgmls |") or 
    die("Unable to open nsgmls parsed data $input");

open (OUT, ">$output") or die ("Unable to open $output for writing\n");

# allocate an object of SGMLS class 
#
$this_parse = new SGMLS(IN);

@KeptTags = ('UTF', 'BN_EPISODE_TRANS', 'CONVERSATION_TRANS',
	     'SECTION', 'TURN', 'B_OVERLAP', 'E_OVERLAP', 
             'B_NOSCORE', 'E_NOSCORE',
             'HYPHEN', 'ACRONYM',
	     'SEPARATOR', 'FRAGMENT', 'NONLEXEME');
$KeptTags_exp = join("|",@KeptTags);

while ($this_event = $this_parse->next_event) {
    local $type = $this_event->type;
    local $data = $this_event->data;

  SWITCH: {
      
      $type eq 'start_element' && do {
	  if ($debug_level > $DEBUG_BRIEF) {
	      print "${DBoff}start".$data->name."\n";
	      ${DBoff} .= "  ";
          }
	  if ($data->name =~ /($KeptTags_exp)/){
	      &proc_print_start_tag($data);
	  } elsif ($data->name eq "NONSPEECH" || $data->name eq "ACOUSTICNOISE"){
	      $skip_to_separator=1;
	  } else {
	      ; #### Swallow it
	  }		  
	  last SWITCH;
      };

      $type eq 'end_element' && do {
	  if ($debug_level > $DEBUG_BRIEF) {
	      ${DBoff} =~ s/..$//; print "${DBoff}end ".$data->name."\n";
          }

	  if ($data->name =~ /($KeptTags_exp)/){
	      &proc_print_end_tag($data);
	  } else {
	      ; #### Swallow it
	  }		  
	  last SWITCH;
      };

      $type eq 'cdata' && do {
	  print "${DBoff}  CDATA ".$data."\n"
	      if ($debug_level > $DEBUG_BRIEF);

	  &proc_cdata($data);

	  last SWITCH;
      };

      $type eq 're' && do {

	  last SWITCH;
      };

      $type eq 'conforming' && do {
	  $conformance = 1;
	  last SWITCH;
      };

      die "Undefined event occurred '$type' in file";
  }
}

if ($conformance == 0) {
    die("Transcript file '$input' does not conform to DTD '$dtd_file'");
}

# close input and output files
#
close (IN);
close (OUT);

# exit normally
#
exit 0;

########################################################
# subroutines
########################################################

sub proc_print_start_tag{
    local($data) = @_;
    local($key);
    

    if ($data->name eq "SEPARATOR"){
	$skip_to_separator=0;
	print OUT " " if (!	$lc_separator);
	$lc_newline=0;
	$lc_separator=1;
    } else {
	if ($data->name eq "HYPHEN" || $data->name eq "FRAGMENT"){
	    print OUT "<",lc($data->name),">";
	    $lc_newline=0;
	} elsif ($data->name eq "ACRONYM"){
	    print OUT "_";
	    $lc_newline=0;
	} elsif ($data->name eq "NONLEXEME"){
	    print OUT "%";
	    $lc_newline=0;
	} else {
	    print OUT "<",lc($data->name);
	    for $key ($data->attribute_names) {
		if (! $data->attribute($key)->is_implied){
		    print OUT " ",lc($key),"=\"" , $data->attribute($key)->value , "\"";
		}
	    }
	    print OUT ">\n";
	    $lc_newline=1;
	}
	$lc_separator=0;
    }
}

sub proc_print_end_tag{
    local($data) = @_;
    local($key);
    if ($data->name !~ /(SEPARATOR|FRAGMENT|HYPHEN|ACRONYM|NONLEXEME|([BE]_(OVERLAP|NOSCORE)))/){
	print OUT "\n" if (!$lc_newline);
	print OUT "</",lc($data->name),">\n";
	$lc_newline=1;
	$lc_separator=0;
    }
}

sub proc_cdata{
    local($data) = @_;

    if (! $skip_to_separator){
	print OUT uc($data);
	$lc_newline = 0;
	$lc_separator=0;
    }
}
