/*
 *  Copyright 1998 Science Applications International Corporation.
 */

/*
 * NAME
 *
 * 
 * FILE 
 *	extentfill.c
 *
 * SYNOPSIS
 *
 * DESCRIPTION
 *	support routines for extentfill data structure.
 *
 * DIAGNOSTICS
 *
 *
 * FILES
 *
 *
 * NOTES
 *	Scratch pad - modification history, plans for enhancements.
 * 
 * SEE ALSO
 *
 * AUTHOR
 *	Aaron Douthat
 *
 */

#ifdef SCCSID
static char SccsId[] = "@(#)extentfill.c	22.1\t12/08/98\tSAIC";
#endif

#undef SCCSID
#include  "muc_defs.h"
#include  "muc.h"
#include  "muc_protos.h"
#include  "muc_globals.h"


/************************************************************************
 *									*
 *  extentfill_create							*
 *									*
 ***********************************************************************/

Extentfill *
extentfill_create(void)
{
    Extentfill *newfill;
    
    if((newfill = UALLOC(Extentfill, 1)) == (Extentfill *) NULL)
    {
	fprintf(stderr, "Error: [extentfill_create]: Allocation failed.\n");
	exit(1);
    }

    newfill->start_offset = 0;
    newfill->end_offset = 0;
    newfill->string_rep = (char *) NULL;

    return(newfill);
}

Extentfill *
extentfill_create_from_attribute(char *tokenstart, 
				 char *tokenfinish)
{
	Extentfill *result;
	
	result = extentfill_create();
	result->string_rep = alloc_between(tokenstart,
					   tokenfinish);
	sscanf(result->string_rep,
	       "%d.%d",
	       &(result->start_offset),
	       &(result->end_offset));

	return result;
}

/************************************************************************
 *									*
 *  extentfill_make_string_rep
 *									*
 ***********************************************************************/

void
extentfill_make_string_rep(Extentfill *extentfill)
{
	char *string_rep;

	assert(extentfill);
		
	string_rep= UALLOC(char,SHORTBUFLENGTH);

	*string_rep='\0';
	sprintf(string_rep,
		"%d.%d",
		extentfill->start_offset,
		extentfill->end_offset);
	UFREE(extentfill->string_rep);

	extentfill->string_rep = string_rep;
}


	

/************************************************************************
 *									*
 *  extentfill_release							*
 *									*
 ***********************************************************************/

void
extentfill_release(char *c_ptr)
{
    Extentfill *extentfill = (Extentfill *) c_ptr;
    
    if(extentfill == (Extentfill *)NULL)
	return;

    /* free the pointer to the allocated text string */
    UFREE(extentfill->string_rep);
    UFREE(extentfill);
}

/*********************************************************************
 * 
 * extentfill_compare -- used in table(3) operations
 *
 ********************************************************************
 */

int
extentfill_compare(char *elt1, char *elt2)
{
	return((int)(elt1 - elt2));
}

/*********************************************************************
 * 
 * extentfill_match -- comparees two extentfills, and returns COR or INC
 *                     also updates tallies
 *
 ********************************************************************
 */

char
extentfill_match(Extentfill *key_extentfill, 
		 Extentfill *response_extentfill,
		 Tallies *tallies)
{
	char result = INC;
	
	assert(key_extentfill && response_extentfill);
	
	if((labs((key_extentfill->start_offset)
		 -
		 (response_extentfill->start_offset))
	    <=
	    MUC_ne_offset_tolerance)
	   
	   &&
	   
	   (labs((key_extentfill->end_offset)
		 -
		 (response_extentfill->end_offset))
	    <=
	    MUC_ne_offset_tolerance))
	{
		tally1_correct( tallies );
		result = COR;
	}		
	else	
	{
		tally1_incorrect( tallies );
		result = INC;
	}
	return result;
}
		

/************************************************************************
 *									*
 *  extentfill_print							*
 *									*
 ***********************************************************************/

void
extentfill_print(Extentfill *extentfill, int indent)
{
	if( extentfill && extentfill->string_rep )
		printf("%s\n",
		       extentfill->string_rep); 
}


