/*
 *  Copyright 1995 Science Applications International Corporation.
 */

/*
 * NAME
 *
 * 
 * FILE 
 *	lexeme.c
 *
 * SYNOPSIS
 *
 * DESCRIPTION
 *	Support routines for lexeme (data + offset) structure.
 *
 * DIAGNOSTICS
 *
 *
 * FILES
 *
 *
 * NOTES
 * 
 * SEE ALSO
 *
 * AUTHOR
 *
 */

#ifdef SCCSID
static char SccsId[] = "@(#)lexeme.c	22.1\t12/08/98\tSAIC";
#endif

#undef SCCSID
#include  "muc_defs.h"
#include  "muc.h"
#include  "muc_protos.h"
#include  "muc_globals.h"


/************************************************************************
 *									*
 *  lexeme_create							*
 *									*
 ***********************************************************************/

Lexeme *
lexeme_create(char *data, long offset, unsigned char altjump)
{
	Lexeme *result;
    
	if((result = UALLOC(Lexeme, 1)) == (Lexeme *) NULL)
	{
		fprintf(stderr, "[lexeme_create]: Allocation failed.\n");
		exit(1);
	}

	result->data = STRALLOC(data);
	result->offset = offset;
	result->altjump = altjump;

	return result;
}	

/************************************************************************
 *									*
 *  lexeme_release							*
 *									*
 ***********************************************************************/

void
lexeme_release(char *c_ptr)
{
	Lexeme *lexeme = (Lexeme *) c_ptr;
    
	if(lexeme == (Lexeme *)NULL)
		return;

	/* free the pointer to the allocated text string */
	UFREE(lexeme->data);
	UFREE(lexeme);
}

/*********************************************************************
 * 
 * lexeme_match -- 
 *
 *
 ********************************************************************
 */

Bool
lexeme_match(Lexeme *key_lexeme, 
	     Lexeme *response_lexeme)
{
	Bool result = False;
	char *p, *q;

	if( key_lexeme && response_lexeme )
		if((! MUC_use_offsets_in_content_matching)
		   ||
		   (key_lexeme->offset == response_lexeme->offset))
		{
			assert(key_lexeme->data);
			assert(response_lexeme->data);
			if(MUC_fragment_prefix_char
			   &&
			   (MUC_fragment_prefix_char == (key_lexeme->data)[0]))
			{
				p = string_lower((key_lexeme->data) + 1);
				q = string_lower((response_lexeme->data));
				result = strstr(p,q) == 0;
				UFREE(p);
				UFREE(q);
			}
			else
			{	
				result = STRCASEEQ(key_lexeme->data,
						   response_lexeme->data);
			}
		}
	

	/* (If we don't use offsets, just look at the data.  But if
	   we do use offsets, first compare the offsets.  If the offsets
	   match, check the data. Otherwise just return false.) */
	
	return result;
}


/************************************************************************
 *									*
 *  lexeme_print							*
 *									*
 ***********************************************************************/

void
lexeme_print(Lexeme *lexeme, int indent)
{
	if(lexeme
	   &&
	   lexeme->data )
		printf("%s %d %d\n", 
		       lexeme->data, 
		       lexeme->offset,
		       lexeme->altjump );
}


