/*
 *  Copyright 1995 Science Applications International Corporation.
 */

/*
 * NAME
 *
 * 
 * FILE 
 *	lexseqfill.c
 *
 * SYNOPSIS
 *
 * DESCRIPTION
 *	Support routines for lexseqfill (lexeme sequence
 *      fill) data structure.
 *
 * DIAGNOSTICS
 *
 *
 * FILES
 *
 *
 * NOTES
 * 
 * SEE ALSO
 *
 * AUTHOR
 *
 */

#ifdef SCCSID
static char SccsId[] = "@(#)lexseqfill.c	22.1\t12/08/98\tSAIC";
#endif

#undef SCCSID
#include  "muc_defs.h"
#include  "muc.h"
#include  "muc_protos.h"
#include  "muc_globals.h"

static void lex_attribute(TABLE *lexemes, char *tokenstart, char *tokenfinish);


/************************************************************************
 *									*
 *  lexseqfill_create							*
 *									*
 ***********************************************************************/

Lexseqfill *
lexseqfill_create(void)
{
	Lexseqfill *result;
    
	if((result = UALLOC(Lexseqfill, 1)) == (Lexseqfill *) NULL)
	{
		fprintf(stderr, "[lexseqfill_create]: Allocation failed.\n");
		exit(1);
	}

	result->lexemes = table_list_create(default_compar,
					    lexeme_release,
					    default_destroy);

	result->straight_lexemes = table_list_create(default_compar,
						     lexeme_release,
						     default_destroy);

	result->clean_lexemes = table_list_create(default_compar,
						  lexeme_release,
						  default_destroy);

	return(result);
}


Lexseqfill *
lexseqfill_create_from_attribute(char *tokenstart, 
				 char *tokenfinish)
{
	Lexseqfill *result;

	result = lexseqfill_create();
	lex_attribute(result->lexemes,
		      tokenstart,
		      tokenfinish);
	return result;
}

static
void
lex_attribute(TABLE *lexemes, char *tokenstart, char *tokenfinish)
{
	Lexeme *lexeme;   /* pointer to created lexemes */
	char *unlexedstr; /* copy of string betw. start and finish */
	char *lex0;       /* pointer to first char of substrings */
	char *lex1;       /* pointer to last char of substrings */
	char *fill;       /* where one lexeme's fill is accumulated */
	char *fillchunk;  /* one piece of lexeme's fill      */
	long offset;      /* lexeme's offset [offset,altjump] */
	long altjump;     /* lexeme's altjump                 */
	

	unlexedstr = alloc_between(tokenstart, tokenfinish);

	lex0 = unlexedstr;
	while(*lex0)
	{
		fill = STRALLOC("");
		while(1)
		{
			/* Find backslash, "[", or end of string */
			lex1 = lex0 + strcspn(lex0, "\\[");
			/* Should never reach end of string before */
			/* an unescaped "[" */
			assert(lex1 && *lex1);

			/* Have reached end of one chunk of lexeme,  */
			/* so stick it on the end of the lexeme fill */
			fillchunk = alloc_between(lex0,
						  lex1);
			fill = (char *)realloc((void *) fill,
					       strlen(fill) +
					       strlen(fillchunk) +
					       1);

			strcat(fill,fillchunk);
			UFREE(fillchunk);

			/* go one past the \ or "[" */
			lex0 = lex1 + 1;

			if(*lex1 == '[')
			{
				/* find "]" */
				lex1 = lex0 + strcspn(lex0, "]");

				/* get the [offset,altjump] info */
				fillchunk = alloc_between(lex0, 
							  lex1);
				sscanf(fillchunk,
				       "%d,%d",
				       &offset,
				       &altjump);

				lexeme = lexeme_create(fill,
						       offset,
						       (unsigned char) altjump);
				table_append((char *)lexeme, 
					     lexemes);

				/* done with both fill and fillchunk */
				UFREE(fill);
				UFREE(fillchunk);
				/* Move to next lexeme's beginning, or */
				/* null-terminator of string. */
				lex0 = lex1 + 1; 
				/* no more of this lexeme */
				break; /* out of while(1) */
			}
		   }
	}
	UFREE(unlexedstr);
}

void
lexseqfill_make_string_rep(Lexseqfill *lexseqfill)
{			
	Lexeme *lexeme;
	int seplen = strlen(MUC_report_lexeme_separator);
	
	char *string_rep;

	string_rep = (char *)malloc(sizeof(char));
	sprintf(string_rep, ""); /* put in the null terminator */
	
	table_first(lexseqfill->lexemes);
	while(lexeme=(Lexeme *)table_next(lexseqfill->lexemes))
	{
		if( lexeme->data )
		{
			string_rep = (char *)realloc((void *) string_rep,
						     strlen(string_rep) +
						     strlen(lexeme->data) +
						     seplen + 1);
			sprintf(string_rep, 
				"%s%s%s",
				string_rep,
				lexeme->data,
				MUC_report_lexeme_separator);
		}
	}
	/* chop off last separator */
	string_rep[strlen(string_rep)-seplen] = '\0';
	UFREE(lexseqfill->string_rep);
	lexseqfill->string_rep = string_rep;
}


/************************************************************************
 *									*
 *  lexseqfill_release							*
 *									*
 ***********************************************************************/

void
lexseqfill_release(char *c_ptr)
{
	Lexseqfill *lexseqfill = (Lexseqfill *) c_ptr;
    
	if(lexseqfill == (Lexseqfill *)NULL)
		return;

	/* free the pointer to the allocated text string */
	table_destroy(lexseqfill->lexemes);
	table_destroy(lexseqfill->straight_lexemes);
	table_destroy(lexseqfill->clean_lexemes);
	UFREE(lexseqfill);
}

/*********************************************************************
 * 
 * lexseqfill_match -- 
 * 
 *  Let the possible lexeme-to-lexeme comparisons form a matrix, 
 *  with rows labelled by the response lexemes and columns labelled
 *  by the key lexemes.  This function looks for a match along some 
 *  diagonal of the matrix.  If a word (i.e. a subsequence of lexemes) 
 *  in the key is "optional," when it doesn't match the response, the 
 *  columns corresponding to the word are jumped over, and the 
 *  comparison continues.
 *  
 ********************************************************************
 */

char
lexseqfill_match(Lexseqfill *key_lexseqfill, 
		 Lexseqfill *response_lexseqfill,
		 Tallies *tallies)
{
	char result = INC;
	TABLE *ktbl;
	TABLE *rtbl;
	Lexeme **ka, **ra;
	int kn, rn, kstart, rstart, ki, ri;
	
	assert( key_lexseqfill && response_lexseqfill );
	ktbl = key_lexseqfill->lexemes;
	rtbl = response_lexseqfill->lexemes;

	kn = table_count(ktbl);
	rn = table_count(rtbl);

	ka = (Lexeme **)table2array(ktbl);
	ra = (Lexeme **)table2array(rtbl);

	/* diagonals above and including the one */
	/* starting at 0,0... */
	kstart = 0;
	while( (kstart < kn) && (result == INC) )
	{
		ri = 0;
		ki = kstart;
		/* each inner loop tests one diagonal. */
		while(1)
		{
			/* Success if the end of the  */
			/* matrix is reached.         */
			if( ki >= kn || ri == rn )
			{
				result = COR;
				break;
			}
			/* If the lexemes match, take one */
			/* step down the diagonal.        */
			else if( lexeme_match(ka[ki],ra[ri]) )
			{
				ki++;
				ri++;
			}
			/* skip over optional words */
			else if( ka[ki]->altjump )
				ki += ka[ki]->altjump;
			/* otherwise, go to next diagonal */
			else
			{
				kstart++;
				break;
			}
		}
	}
	/* diagonals below the one starting at 0,0... */
	rstart = 1;
	while( (rstart < rn) && (result == INC) )
	{
		ki = 0;
		ri = rstart;
		while(1)
		{
			if( ki >= kn || ri == rn )
			{
				result = COR;
				break;
			}
			else if( lexeme_match(ka[ki],ra[ri]) )
			{
				ki++;
				ri++;
			}
			else if( ka[ki]->altjump )
				ki += ka[ki]->altjump;
			else
			{
				rstart++;
				break;
			}
		}
	}

	if( result == COR )
		tally1_correct(tallies);
	else
		tally1_incorrect(tallies);

	UFREE( ka );
	UFREE( ra );
	return result;
}


/************************************************************************
 *									*
 *  lexseqfill_print							*
 *									*
 ***********************************************************************/

void
lexseqfill_print(Lexseqfill *lexseqfill, int indent)
{
	Lexeme *l;
	
	if(lexseqfill
	   &&
	   lexseqfill->lexemes )
	{
		table_first( lexseqfill->lexemes );
		while( l = (Lexeme*)table_next( lexseqfill->lexemes ) )
			lexeme_print(l, indent);
		printf("\n");
	}
}


