%{
/*
 *  Copyright 1997 Science Applications International Corporation.
 */

/*
 * NAME
 *
 * 
 * FILE 
 *	@(#)markup.l	22.1 12/08/98
 *
 * SYNOPSIS
 *
 *
 * DESCRIPTION
 *      parser for sgml
 *     
 *
 * DIAGNOSTICS
 *
 *
 * FILES
 *
 *
 * NOTES
 * 
 * SEE ALSO
 *
 * AUTHOR
 */

#ifdef SCCSID
static char SccsId[] = "@(#)markup.l	22.1\t12/08/98\tSAIC";
#endif

#undef SCCSID
#include  "muc_defs.h"
#include  "muc.h"
#include  "muc_protos.h"
#include  "muc_globals.h"


static char cur_docnum[BUFLENGTH];
static char *cur_classname = NULL;
static long cur_instnum = 0;
static char *cur_slotname;
static char *cur_lexeme;

static Catalog_entry *cur_catalog_entry;
static Clas *cur_clas;
static Inst *cur_inst;
static Slot *cur_slot;
static Mfil *cur_mfil;
static Sfil *cur_sfil;

static TABLE *doc_section_stack;
static TABLE *cur_inst_stack;

static Class_def *cur_class_def;
static Slot_def *cur_slot_def;

/* in case we're using a version of flex that */
/* defines yywrap() as a macro...             */
#undef yywrap
int yywrap();
void yyerror(const char *msg);


/* local functions */

static Bool is_task_tag( char *tag );
static Bool is_lex_sep_tag( char *tag );
static Bool is_doc_tag( char *tag );
static Bool is_doc_section_tag( char *tag );
static void start_new_catalog_entry();

static void insert_all_insts_into_cur_entry();
static void start_cur_inst( char *tag );
static void finish_cur_inst( char *tag );
static void pop_inst_from_cur_inst_stack( Inst *inst );

static void add_text_to_cur_insts(char *lexeme);
static void add_text_to_inst_text_slot(Inst *inst, char *lexeme);
static void add_slots_to_cur_inst( char *tag );

static void add_slot_to_cur_inst( char *attname, char *attvalue );
static void add_mfils_to_cur_slot(char *attvalue);
static void add_sfil_to_cur_mfil(char *tokenstart, char *tokenfinish);

static void add_text_to_cur_lexeme(char *s);
static void add_lexeme_to_cur_insts(char *l, char *l_tag );
static void add_lexeme_to_inst_content_slot(Inst *inst, 
					    char *lexeme,
					    unsigned char altjump);
static unsigned char get_altjump_from_lexeme_tag(char *tag);

static Sfil *find_sfil_to_put_data(Inst *inst, 
				   Mfil **mfil,
				   Sfil **sfil,
				   char *optionname);
static void push_doc_section( char *tag );
static void pop_doc_section( char *tag );

static void pop_gi_from_doc_section_stack( char *gi );
static char *get_gi_from_tag( char *tag );
static void change_newline_to_space( char *string );

%}

%s TASKOPEN TASKCLOSE

%%
%{

/* initialize tables  */

doc_section_stack = table_list_create(cstring_compare,
				      default_release,
				      default_destroy);

cur_inst_stack = table_list_create(inst_compare,
				   NULL,
				   default_destroy);

%}
%{

   /* SGML open tag */

%}
"<"[^/][^<>]*">"	          {

	if( is_task_tag( yytext ) )
	{
		/* push inst onto inst stack and parse tag */
		change_newline_to_space( yytext );
		start_cur_inst( yytext );
	}
	else 
	{
		if( is_doc_tag( yytext ) )
			start_new_catalog_entry();

		if( is_doc_section_tag( yytext ) )
			push_doc_section( yytext );
		
		/* if MUC_count_sgml is true, we can't be */
		/* using lexeme tags (see init_muc.c), so */
		/* we don't check.                        */
		if( MUC_count_sgml )
		{
			add_text_to_cur_insts( yytext );
			MUC_cur_text_charno += yyleng;
		}
	}
}
%{

   /* SGML close tag */

%}
"</"[^<>]*">"	          {

	if( is_task_tag( yytext ) )
		/* pops inst from inst stack */
		finish_cur_inst( yytext );
	else 
	{
		/* end of doc section */
		if( is_doc_section_tag( yytext ) )
			pop_doc_section( yytext );

		/* if MUC_count_sgml is true, we can't be */
		/* using lexeme tags, so don't check.     */
		if( MUC_count_sgml )
		{
			add_text_to_cur_insts( yytext );
			MUC_cur_text_charno += yyleng;
		}
	}
}
%{

   /* anything else (except newlines) */

%}
[^<>\n]*|"<"|">"            {
	
	if( MUC_extract_from_text )
	{
		add_text_to_cur_insts( yytext );
		MUC_cur_text_charno += yyleng;
	}
}
%{

   /* newlines */

%}
\n            {

	if( MUC_extract_from_text )
	{
		add_text_to_cur_insts( " " );
		MUC_cur_text_charno += yyleng;
	}

	MUC_cur_lineno++;
}
%%

/**************************************************/
/**************************************************/

static
Bool
is_task_tag( char *tag )
{
	Bool result;
	char *gi;
	
	gi = get_gi_from_tag( tag );
	
	if( class_def_find( MUC_Class_defs, gi ))
		result = True;
	else
		result = False;

	UFREE( gi );
	return result;
}

/**************************************************/
/**************************************************/

static
Bool
is_lex_sep_tag( char *tag )
{
	Bool result;
	char *gi;
	
	if( MUC_lexeme_separator_GIDs == NULL )
		result = False;
	else 
	{
		gi = get_gi_from_tag( tag );
		
		if( table_find( gi, MUC_lexeme_separator_GIDs ))
			result = True;
		else
			result = False;
		
		UFREE( gi );
	}
	
	return result;
}

/**************************************************/
/**************************************************/

static
Bool
is_doc_tag( char *tag )
{
	Bool result;
	char *gi;
	char *doc_tag_string = 
		option_find_first_value(MUC_Options, 
					":sgml_DOC_gid");
	gi = get_gi_from_tag( tag );

	if( STRCASEEQ( doc_tag_string, gi ) )
		result = True;
	else
		result = False;
	
	UFREE( gi );
	return result;
}

/**************************************************/
/**************************************************/

static
Bool
is_doc_section_tag( char *tag )
{
	Bool result;
	char *gi;
	TABLE *doc_sections = 
		option_find_values(MUC_Options,
				   ":doc_sections");
	
	gi = get_gi_from_tag( tag );
	
	if( table_find( gi, doc_sections ) )
		result = True;
	else
		result = False;

	UFREE(gi);
	return result;
}


/**************************************************
 *
 * start_new_catalog_entry
 *
 **************************************************/

static
void
start_new_catalog_entry()
{
	Inst *inst;
	Clas *clas;
	TABLE *classes;
	char *doc_section;

	/* calculate the current docnum */
	MUC_cur_docnum_count++;
	printf("%d ",MUC_cur_docnum_count );fflush(stdout);
	sprintf(cur_docnum, "%d", MUC_cur_docnum_count);

	/* get entry from catalog */
	cur_catalog_entry = catalog_entry_find(MUC_Catalog, cur_docnum);
	if( cur_catalog_entry == NULL )
	{
		cur_catalog_entry = catalog_entry_create(cur_docnum);
		table_append((char *)cur_catalog_entry, MUC_Catalog);
	}

	/* reset the "helper" tables -- shouldn't hurt insts */
	/* (first warn if the tables aren't empty) */
	if( table_count(doc_section_stack) )
	{
		table_first(doc_section_stack);
		for(doc_section=table_next(doc_section_stack);
		    doc_section;
		    doc_section=table_next(doc_section_stack))
			fprintf(stderr, 
				"\'%s\' open tag without close, inserting\n",
				doc_section);
	}
	table_destroy( doc_section_stack );
	doc_section_stack = table_list_create(cstring_compare,
					      default_release,
					      default_destroy);

	if( table_count( cur_inst_stack ))
	for(inst=(Inst*)table_next(cur_inst_stack);
	    inst;
	    inst=(Inst*)table_next(cur_inst_stack))
		fprintf(stderr, 
			"Line %d: \'%s\' open tag without close tag, assuming close tag goes here\n",
			MUC_cur_lineno,
			inst->name);

	/* reset the current inst stack */
	table_destroy( cur_inst_stack );
	cur_inst_stack = table_list_create(inst_compare,
					   NULL,
					   default_destroy);

	cur_instnum = 0;
			
	if( MUC_reset_doc_offsets )
	{
		MUC_cur_text_charno = 0;
	}
}

/*************************************************
 *
 * start_cur_inst -- put the instances in the catalog until the end of the
 *     document, when the docnum has (surely!) been found.
 *
 **************************************************/

static
void
start_cur_inst( char *tag )
{
	char instnum[BUFLENGTH];
	TABLE *classes;
	Clas *clas;
	char *doc_section;
	char *gi;
	
	gi = get_gi_from_tag( tag );
	
	/* are we in a doc section that we're interested in? */
	table_first(doc_section_stack);
	doc_section = table_next(doc_section_stack);
	if( doc_section )
	{
		cur_class_def = class_def_find( MUC_Class_defs, gi );
		if(  cur_class_def == NULL )
		{
			fprintf(stderr,
				"unknown tag type in %s",
				tag);
			exit(1);
		}
		
		sprintf(instnum, "%d", ++cur_instnum );
		cur_inst = inst_create( gi, cur_docnum, instnum );

		cur_inst->its_class_def = cur_class_def;
		cur_inst->is_instantiated = True;
		if( MUC_key_or_response == KEY )
			cur_inst->is_key = True;

		add_slots_to_cur_inst( tag );

		/* This start offset is used for mapping */
		/* "pre-qualification".  The offsets in  */
		/* stringfill/extentfills are put in      */
		/* when the attributes are parsed         */
		cur_inst->start_offset = MUC_cur_text_charno;
		cur_inst->doc_section = STRALLOC(doc_section);

		/* insert cur_inst in cur_entry */
		/* set class list, based on whether parsing key or response */
		assert( cur_catalog_entry );
		
		if( MUC_key_or_response == KEY )
			classes = cur_catalog_entry->key_classes;
		else
			classes = cur_catalog_entry->response_classes;
		
		/* put proper document number in inst */
		UFREE( cur_inst->docnum );
		cur_inst->docnum = STRALLOC(cur_docnum);

		/* put inst in its class */
		clas = clas_find( classes, cur_inst->name );
		table_append((char *)cur_inst, clas->insts);

		/* also, push inst on top of cur inst stack */
		table_prepend((char *)cur_inst, cur_inst_stack);
	}
	UFREE(gi);
}

/**************************************************/
/**************************************************/

static
void
finish_cur_inst( char *tag )
{
	Inst *inst;
	char *gi;
	Bool instack;
	
	gi = get_gi_from_tag( tag );
	
	/* see if inst by that name in stack */
	instack = False;
	table_first(cur_inst_stack);
	for(inst=(Inst *)table_next(cur_inst_stack);
	    (inst && (!instack));
	    inst=(Inst *)table_next(cur_inst_stack))
		if(STRCASEEQ(gi, inst->name))
			instack = True;

	if( instack )
	{
		table_first(cur_inst_stack);
		inst=(Inst *)table_next(cur_inst_stack);
		while( inst && !STRCASEEQ(gi,inst->name) )
		{
			fprintf(stderr,
				"Line %d:  \'%s\' open tag without close tag, assuming close tag goes here\n",
				MUC_cur_lineno,
				inst->name);

			pop_inst_from_cur_inst_stack(inst);

			/* reset table and look at top again */
			table_first(cur_inst_stack);
			inst=(Inst *)table_next(cur_inst_stack);
		}

		/* now, take out inst that corresponds to the tag */
		pop_inst_from_cur_inst_stack(inst);
		
		/* reset table and look at top again */
		table_first(cur_inst_stack);
		cur_inst=(Inst *)table_next(cur_inst_stack);
	}
	else
		fprintf(stderr,
			"Line %d:  \'%s\' close tag with no open tag\n",
			MUC_cur_lineno,
			gi);
	UFREE(gi);
}


/**************************************************/

static
void
pop_inst_from_cur_inst_stack( Inst *inst )
{			
	/* record where in the text the inst text ends */
	inst->end_offset = MUC_cur_text_charno;
	
	/* ensure there's a TEXT or CONTENT slot in the inst */
	if( ! MUC_lexeme_separator_GIDs )
		add_text_to_cur_insts("");

	/* pop */
	table_delete((char *)inst, cur_inst_stack);
}

/**************************************************/

static
void
add_text_to_cur_insts(char *lexeme)
{
	Inst *inst;
	if( lexeme )
	{
		table_first(cur_inst_stack);
		while(inst=(Inst *)table_next(cur_inst_stack))
			add_text_to_inst_text_slot(inst, lexeme);
	}
}

/**************************************************/

static
void
add_text_to_inst_text_slot(Inst *inst, char *lexeme)
{
	char *slotname;
	Slot_def *slot_def;
	Mfil *mfil;
	Sfil *sfil;

	find_sfil_to_put_data(inst, &mfil, &sfil, ":sgml_TEXT_slot");
	
	if(sfil == NULL)
	{
		sfil = sfil_create(STRING_FILL);
		sfil->fill.str->fill = STRALLOC(lexeme);
		sfil->fill.str->start_offset = MUC_cur_text_charno;
		sfil->fill.str->end_offset = MUC_cur_text_charno + strlen(lexeme) - 1;
		table_append((char *)sfil, mfil->sfils);
	}
	else if( sfil->fill.str->fill == NULL )
	{
		fprintf(stderr,
			"Line %d: add_text_to_inst_text_slot: NULL string fill\n",
			MUC_cur_lineno);
		exit(1);
        }		
	else
	{
		sfil->fill.str->fill = 
			(char *)realloc((void *)sfil->fill.str->fill, 
					strlen( sfil->fill.str->fill ) + 
					strlen(lexeme) + 1 );
		strcat( sfil->fill.str->fill, lexeme );
		sfil->fill.str->end_offset += strlen(lexeme);		
	}
}

/**************************************************/
/**************************************************/

/**************************************************/

static
void
add_lexeme_to_cur_insts(char *lexeme, char *tag)
{
	Inst *inst;
	unsigned char altjump;
	
	altjump = get_altjump_from_lexeme_tag(tag);
	
	if( lexeme )
	{
		table_first(cur_inst_stack);
		while(inst=(Inst *)table_next(cur_inst_stack))
			add_lexeme_to_inst_content_slot(inst, 
							lexeme,
							altjump);
	}
}

/**************************************************/

static
unsigned char
get_altjump_from_lexeme_tag(char *tag)
{
	int result = 0;
	char *p1 = tag;
	char *p2;
	char *altjump;
	
	if( p1 )
	{
		p1 += strspn( p1, "<" );     /* skip open '<' */
		p1 += strcspn(p1, " \t\n>");  /* skip gid      */
		p1 += strspn( p1, " \t\n");  /* skip space    */
		if( *p1 != '>' )
		{
			p1 += strcspn( p1, "=>" );
			if( *p1 == '=' )
				p1++;
			else
			{
				fprintf(stderr,
					"bad lexeme separator tag: \'%s\'\n",
					tag);
				exit(1);
			}
			p1 += strspn( p1, " \n\t\"\'" );
			p2 = p1 + strcspn( p1, " \n\t\"\'>" );

			altjump = alloc_between( p1, p2 );
			sscanf( altjump, "%d", &result );
			UFREE( altjump );

			p2 += strspn( p2, "\"\'>" );
		}
	}
	return (unsigned char)result;
}

/**************************************************/

static
void
add_lexeme_to_inst_content_slot(Inst *inst, 
				char *lexeme_data, 
				unsigned char altjump)
{
	Mfil *mfil;
	Sfil *sfil;
	Lexeme *lexeme;

	find_sfil_to_put_data(inst, &mfil, &sfil, ":sgml_CONTENT_slot");

	if(sfil == NULL)
	{
		sfil = sfil_create(LEXSEQ_FILL);
		table_append((char *)sfil, mfil->sfils);
	}

	/* anal-retentive checking of NULL pointers . . . */
	if((sfil->fill.lsq == NULL)
	   ||
	   (sfil->fill.lsq->lexemes == NULL))
	{
		fprintf(stderr,
			"NULL lexeme sequence fill\n");
		exit(1);
        }		
	/* finally, add a copy of the lexeme to the lexseq fill */
	else
	{
		lexeme = lexeme_create(lexeme_data, MUC_cur_text_charno, altjump);
		table_append((char *)lexeme, sfil->fill.lsq->lexemes);
	}
}

/**************************************************/

static
Sfil *
find_sfil_to_put_data(Inst *inst, 
		      Mfil **mfil,
		      Sfil **sfil,
		      char *optionname)
{
	char *slotname;
	Slot_def *slot_def;
	Slot *slot;
	
	slotname = option_find_first_value(MUC_Options,
					   optionname);
	
	slot_def = 
		slot_def_find(inst->its_class_def->slot_defs,
			      slotname);

	/* find the content slot in the inst, or create it */
	slot = slot_find(inst->slots, slotname);
	if(slot == NULL)
	{
		slot = slot_create(slotname);
		slot->its_slot_def = slot_def;
		table_append((char *)slot, inst->slots);
	}
	
	/* find the first mfil in the slot, or create it */
	table_first(slot->mfils);
	*mfil = (Mfil *)table_next(slot->mfils);
	if(*mfil == NULL)
	{
		*mfil = mfil_create();
		table_append((char *)(*mfil), slot->mfils);
	}
	
	/* find the first sfil in the mfil, or create it.   */
	table_first((*mfil)->sfils);
	*sfil = (Sfil*)table_next((*mfil)->sfils);
}


static
void
add_slots_to_cur_inst( char *tag )
{
	char *ptr1 = tag;
	char *ptr2;
	char *attname;
	char *attvalue;
	Slot *slot;
	char firstchar;
	
	ptr1++;                                         /* skip > */
	ptr1 += strcspn( ptr1, " \t\n>" );              /* skip gi */
	ptr1 += strspn( ptr1, " \t\n" );                /* skip spaces */
	while( (*ptr1) != '>' )
	{
		ptr2 = ptr1 + strcspn( ptr1, " \t\n=" );   /* get slot name */
		attname = alloc_between( ptr1, ptr2 );
		ptr1 = ptr2 + strspn( ptr2, " \t\n" );     /* skip spaces */
		if( (*ptr1) != '=' )
		{
			fprintf(stderr, 
				"Line %d:  tag missing \'=\' after attribute \'%s\'\n",
				MUC_cur_lineno,
				attname);
			UFREE( attname );
			continue;                          /* no att value => empty slot */
		}
		ptr1++;                                    /* skip = */
		ptr1 += strspn( ptr1, " \t\n" );          /* skip spaces */
		firstchar = (*ptr1);
		if((firstchar == '"') || (firstchar == '\'')){
			ptr1++;                            /* go past open quote */
			ptr2 = ptr1;
			while(((*ptr2) != '>')             /* find close quote */
			      && 
			      ((*ptr2) != firstchar))
				ptr2++;
		}
		else
			ptr2 = ptr1 + strcspn( ptr1, " \t\n>" ); /* find char after att*/
		attvalue = alloc_between( ptr1, ptr2 );
		add_slot_to_cur_inst( attname, attvalue );
		UFREE(attname);
		UFREE(attvalue);
		if( (*ptr2 == '\"') || (*ptr2 == '\'') )	/* " go past close quote */
			ptr2++;
		ptr2 += strspn( ptr2, " \t\n" );             /* skip spaces */
		ptr1 = ptr2;
	}
}

/**************************************************/

static
void
add_slot_to_cur_inst( char *attname, char *attvalue )
{
	UFREE( cur_slotname );
	cur_slotname = STRALLOC( attname );
	
	if( cur_class_def == NULL )  /* shouldn't ever happen */
	{
		fprintf(stderr,
			"Line %d:  [start_cur_slot]:current class def NULL\n",
			MUC_cur_lineno);
		exit(1);
	}

	/* find current slot definition */
	cur_slot_def = slot_def_find( cur_class_def->slot_defs, cur_slotname );
	if( cur_slot_def == NULL )
	{
		/* complain then return */
		fprintf(stderr,
			"Line %d:  Undeclared attribute \'%s\'\n",
			MUC_cur_lineno,
			cur_slotname);
		UFREE( cur_slotname );
		return;
	}

	/* check if slot has already been filled */
	cur_slot = slot_find(cur_inst->slots, cur_slotname);
	if(cur_slot)
	{
		fprintf(stderr,
			"Line %d:  multiple \'%s\' attributes in tag, using last one.\n",
			MUC_cur_lineno,
			cur_slotname);
		table_delete((char *)cur_slot, cur_inst->slots);
	}
	cur_slot = slot_create(cur_slotname);
	cur_slot->its_slot_def = cur_slot_def;
	
	add_mfils_to_cur_slot( attvalue );

	table_append((char *)cur_slot, cur_inst->slots);
}

/**************************************************/
/**************************************************/

static
void
add_mfils_to_cur_slot(char *attvalue)
{
	char *mfil_sep_str;    /* separator char got from options */
	char *bufptr = attvalue;
	char *endptr;
	char *tokenstart;
	
	mfil_sep_str =
		option_find_first_value(MUC_Options,
					":sgml_alternative_separator");

	while( *bufptr )
	{
		tokenstart = bufptr;        /* save start of mfil  */
		                            /* go past end of mfil */

		endptr = strstr(bufptr, mfil_sep_str);
		if( endptr )
			bufptr = endptr;
		else
			bufptr += strlen(bufptr);
		
		cur_mfil = mfil_create();   /* create mfil and insert */
		table_append((char *)cur_mfil, cur_slot->mfils );

		add_sfil_to_cur_mfil(tokenstart,bufptr);  /* insert sfil in mfil */
		if( *bufptr )                   /* go past separator */
			bufptr++;
	}
}

	

/**************************************************/
/**************************************************/

static
void
add_sfil_to_cur_mfil(char *tokenstart, char *tokenfinish)
{
	int type = slot_def_which_type(cur_slot_def);
	
	cur_sfil = sfil_create_from_attribute(type,
					      tokenstart,
					      tokenfinish);
	table_append((char *)cur_sfil, cur_mfil->sfils);
}

/**************************************************/

static
void
add_text_to_cur_lexeme(char *s)
{
	if( cur_lexeme == NULL )
		cur_lexeme = STRALLOC(s);
	else
	{
		cur_lexeme = 
			(char *)realloc((void *)cur_lexeme, 
					strlen( cur_lexeme ) + 
					strlen( s ) + 1 );
		strcat( cur_lexeme, s );
	}
}

/**************************************************/
/**************************************************/

static
void
push_doc_section( char *tag )
{
	char *gi = get_gi_from_tag(tag);
	
	if((!MUC_allow_nested_doc_sections_of_same_type)
	   &&
	   table_find( gi, doc_section_stack ) )
	{
		pop_gi_from_doc_section_stack( gi );
		fprintf(stderr,
			"Line %d:  '%s' tag inside '%s' element, assuming close tag missing\n",
			MUC_cur_lineno,
			gi,
			gi);
	}

	table_prepend(gi, doc_section_stack);
}

/**************************************************/
/**************************************************/

static
void
pop_doc_section( char *tag )
{
	char *gi = get_gi_from_tag(tag);
	
	if( table_find( gi, doc_section_stack ) )
		pop_gi_from_doc_section_stack( gi );
	else
		fprintf(stderr,
			"Line %d:  \'%s\' close tag with no open tag\n",
			MUC_cur_lineno,
			gi);	
	UFREE( gi );
}

/**************************************************/
/**************************************************/

static
void
pop_gi_from_doc_section_stack( char *gi )
{
	char *top_doc_section;
	
	table_first( doc_section_stack );
	top_doc_section = table_next(doc_section_stack);
	while( top_doc_section && !STRCASEEQ(top_doc_section, gi))
	{
		fprintf(stderr,
			"Line %d:  \'%s\' open tag without close tag, assuming close tag goes here\n",
			MUC_cur_lineno,
			top_doc_section);
		table_delete(top_doc_section, 
			     doc_section_stack);
		table_first( doc_section_stack );
		top_doc_section = table_next(doc_section_stack);
	}
	table_delete(top_doc_section, doc_section_stack);
}	

/**************************************************/
/**************************************************/

static
char *
get_gi_from_tag( char *tag )
{
	char *gi, *gistart, *giend;
	
	gistart = tag;

	/* skip over "<" (and "/") */
	gistart++;
	if( (*gistart) == '/' )
		gistart++;
	giend = gistart;

	/* find end of GI */
	giend += strcspn( giend, " \t\n>" );
	gi = alloc_between( gistart, giend );

	return gi;
}

static
void
change_newline_to_space( char *string )
{
	char *ptr = string;
	while( *ptr )
	{
		if( (*ptr) == '\n' )
		{
			(*ptr) = ' ';
			MUC_cur_lineno++;
		}
		ptr++;
	}
}


/**************************************************/
/**************************************************/

/*
 * yyerror 
 */

void
yyerror(const char *msg)
{
    printf("(markup) %s at '%s'\n", msg, yytext);
}

/* 
 * yywrap -- what to do at the end of the file
 */

int
yywrap(void)
{
	UFREE(cur_classname);
	UFREE(cur_slotname);
	table_destroy(doc_section_stack);
	table_destroy(cur_inst_stack);
	return 1;
}
