/*
 *  Copyright 1995 Science Applications International Corporation.
 */

/*
 * FILE 
 *	@(#)massage.c	22.1\t12/08/98
 *
 * SYNOPSIS
 *
 *
 * DESCRIPTION
 *      stuff to do after parsing but before aligning keys and responses
 *
 * DIAGNOSTICS
 *
 *
 * FILES
 *
 *
 * NOTES
 * 
 * SEE ALSO
 *
 * AUTHOR
 */

#ifdef SCCSID
static char SccsId[] = "@(#)massage.c	22.1\t12/08/98\tSAIC";
#endif

#undef SCCSID
#include  "muc_defs.h"
#include  "muc.h"
#include  "muc_protos.h"
#include  "muc_globals.h"


static void check_status_slots_in_classes(TABLE *classes);
static void check_status_slots_in_insts( TABLE *insts );

static void clas_check_offset_slots(TABLE *classes);
static void inst_check_offset_slots( TABLE *insts );
static void copy_offsets(Sfil *sfil, Inst *inst);

static void clas_make_string_rep(Clas *clas);
static void inst_make_string_rep(Inst *inst);
static void slot_make_string_rep(Slot *slot);
static void mfil_make_string_rep(Mfil *mfil);

void
check_status_slots_in_entry(Catalog_entry *entry)
{
	check_status_slots_in_classes(entry->key_classes);
	check_status_slots_in_classes(entry->response_classes);
}

static
void
check_status_slots_in_classes(TABLE *classes)
{
	Clas *clas;
	
	table_first(classes);
	for(clas = (Clas *)table_next(classes);	
	    clas;
	    clas = (Clas *)table_next(classes))
		check_status_slots_in_insts( clas->insts );
}

static
void
check_status_slots_in_insts( TABLE *insts )
{
	Inst *inst;
	char *slotname;
	Slot *slot;
	char *fill;
	TABLE *values;
	char *value;
	
	slotname = option_find_first_value(MUC_Options,
					   ":optional_status_slot");
	
	table_first(insts);
	for(inst=(Inst *)table_next(insts);
	    inst;
	    inst=(Inst *)table_next(insts))
	{
		slot = slot_find(inst->slots, slotname);
		if( slot )
			inst->is_optional = True;
	}
}

void
entry_check_offset_slots(Catalog_entry *entry)
{
	clas_check_offset_slots(entry->key_classes);
	clas_check_offset_slots(entry->response_classes);
}

static
void
clas_check_offset_slots(TABLE *classes)
{
	Clas *clas;
	
	table_first(classes);
	for(clas = (Clas *)table_next(classes);	
	    clas;
	    clas = (Clas *)table_next(classes))
		inst_check_offset_slots( clas->insts );
}

static
void
inst_check_offset_slots( TABLE *insts )
{
	Inst *inst;
	char *slotname;
	Slot *slot;
	Mfil *mfil;
	Sfil *sfil;
	
	char *fill;
	
	TABLE *values;
	char *value;
	
	slotname = option_find_first_value(MUC_Options,
					   ":sgml_offset_attribute");
	
	table_first(insts);
	for(inst=(Inst *)table_next(insts);
	    inst;
	    inst=(Inst *)table_next(insts))
	{
		slot = slot_find(inst->slots, slotname);
		if( slot )
		{
			table_first(slot->mfils);
			mfil = (Mfil*) table_next(slot->mfils);
			if( mfil )
			{
				table_first(mfil->sfils);
				sfil=(Sfil*)table_next(mfil->sfils);
				if(sfil)
					copy_offsets(sfil,inst);
			}
			
		}
	}
}

static
void
copy_offsets(Sfil *sfil, Inst *inst)
{
	if( sfil->type == EXTENT_FILL )
	{
		assert(sfil->fill.ext);
		inst->start_offset = sfil->fill.ext->start_offset;
		inst->end_offset = sfil->fill.ext->end_offset;		
	} 
	else
		fprintf(stderr,
			"Warning: fill used to determine offsets is not",
			"of type \'extent\'\n");
}

	
void
entry_make_string_rep(Catalog_entry *entry)
{
	Clas *clas;
	
	if( entry )
	{
		if( entry->key_classes )
		{
			table_first( entry->key_classes );
			while(clas=(Clas*)table_next(entry->key_classes))
				clas_make_string_rep(clas);
		}
		if( entry->response_classes )
		{
			table_first( entry->response_classes );
			while(clas=(Clas*)table_next(entry->response_classes))
				clas_make_string_rep(clas);
		}
	}
}

static
void
clas_make_string_rep(Clas *clas)
{
	Inst *inst;
	
	if( clas )
	{
		if( clas->insts )
		{
			table_first(clas->insts);
			while(inst=(Inst *)table_next(clas->insts))
				inst_make_string_rep(inst);
		}
	}
}

static
void
inst_make_string_rep(Inst *inst)
{
	Slot *slot;
	
	if(inst)
	{
		if(inst->slots)
		{
			table_first(inst->slots);
			while(slot=(Slot*)table_next(inst->slots))
				slot_make_string_rep(slot);
		}
	}
}

static
void
slot_make_string_rep(Slot *slot)
{
	Mfil *mfil;
	
	if(slot)
	{
		if(slot->mfils)
		{
			table_first(slot->mfils);
			while(mfil=(Mfil*)table_next(slot->mfils))
				mfil_make_string_rep(mfil);
		}
	}
}

static
void
mfil_make_string_rep(Mfil *mfil)
{
	Sfil *sfil;
	
	if(mfil)
	{
		if(mfil->sfils)
		{
			table_first(mfil->sfils);
			while(sfil=(Sfil*)table_next(mfil->sfils))
				sfil_make_string_rep(sfil);
		}
	}
}


			      
			
			
