/* @(#)msort.c	22.1	12/08/98 */

/* Mergesort implementation, adapted from Mark Allen Weiss' 
   "Data Structures and Algorithms", first edition, 
   Benjamin Cummings, 1992, pp. 223-228.  */

/* "msort" should only be used to sort arrays of pointers. */
/* The "width" parameter is only there to make msort       */
/* look like the qsort library function, and calculate the */
/* size of the temporary array.  If you try to             */
/* sort an array of char or some struct with a funny size, */
/* you'll get funny results!                               */

#ifdef SCCSID
static char SccsId[] = "@(#)msort.c	22.1\t12/08/98\tSAIC";
#endif

#undef SCCSID
#include  "muc_defs.h"
#include  "muc.h"
#include  "muc_protos.h"
#include  "muc_globals.h"

static void mergesort(void *a[], void *tmp_array[], int left, int right,
		      int (*compar) (void *, void *));
static void merge(void *a[], void *tmp_array[], int l_pos, int r_pos, 
		  int right_end, int (*compar) (void *, void *));



void 
msort(void *base, size_t nel, size_t width,
      int (*compar) (void *, void *))
{
	void **tmp_array;
	
	if( (tmp_array = malloc(nel*width)) == NULL )
	{
		fprintf(stderr,
			"Can't malloc in msort\n");
		exit(1);
	}

	mergesort((void **)base,tmp_array,0,nel-1,compar);

	free(tmp_array);
}


static
void
mergesort(void *a[], void *tmp_array[], int left, int right,
	  int (*compar) (void *, void *))
{
	int center;
	
	if ( left < right )
	{
		center = (left + right) / 2;
		mergesort(a, tmp_array, left, center, compar);
		mergesort(a, tmp_array, center+1, right, compar);
		merge(a, tmp_array, left, center+1, right, compar);
	}
}

	
/* l_pos = start of left half, r_pos = start of right half */

static
void
merge(void *a[], void *tmp_array[], int l_pos, int r_pos, int right_end, 
      int (*compar) (void *, void *))
{
	int left_end;
	int num_elements;
	int tmp_pos;
	int i;

	left_end = r_pos - 1;
	tmp_pos = l_pos;
	num_elements = right_end - l_pos + 1;
	
	/* main loop */
	while((l_pos <= left_end) && (r_pos <= right_end))
	{
		if ((*compar)(a[l_pos], a[r_pos]) <= 0)
			tmp_array[tmp_pos] = a[l_pos++];
		else 
			tmp_array[tmp_pos] = a[r_pos++];
		tmp_pos++;
	}

	/* copy rest of first half */
	while( l_pos <= left_end )
		tmp_array[tmp_pos++] = a[l_pos++];

	/* copy rest of second half */
	while( r_pos <= right_end )
		tmp_array[tmp_pos++] = a[r_pos++];

	/* copy tmp_array back */
	for( i=0; i<num_elements; i++ )
		a[right_end] = tmp_array[right_end--];
}

