/*
 * NAME
 * 
 * FILE 
 *     @(#)report_summary_NE.c	22.1	12/08/98
 *
 * SYNOPSIS
 *
 * DESCRIPTION
 *
 * DIAGNOSTICS
 *
 * FILES
 *
 * SEE ALSO
 *
 * AUTHOR
 * 
 */

#ifdef SCCSID
static char SccsId[] = "@(#)report_summary_NE.c	22.1\t12/08/98\tSAIC";
#endif

#undef SCCSID
#include  "muc_defs.h"
#include  "muc.h"
#include  "muc_protos.h"
#include  "muc_globals.h"

static void get_all_inst_pairs(TABLE *all_inst_pairs, TABLE *clas_pairs);
static void display_header();

static void display_report_summary_header_NE(Catalog_entry *entry);
static void get_all_inst_pairs(TABLE *all_inst_pairs, TABLE *clas_pairs);
static void display_inst_pairs(TABLE *inst_pairs);
static void display_inst_pair(Inst_pair *inst_pair);
static void display_slot_pair(Slot_pair *slot_pair);
static void display_sfil_pair(Sfil_pair *sfil_pair);
static void make_status_string(char status,
			       char *status_string);
static Sfil_pair *get_scored_sfil_pair(TABLE *mfil_pairs);


void
display_report_summary_NE(Catalog_entry *entry)
{
	TABLE *all_inst_pairs;
	TABLE *sorted_inst_pairs;

	all_inst_pairs = table_list_create(default_compar,
					   NULL,
					   default_destroy);
	sorted_inst_pairs = table_list_create(default_compar,
					      NULL,
					      default_destroy);
	get_all_inst_pairs(all_inst_pairs, entry->clas_pairs);
	inst_pair_sort_by_offset(sorted_inst_pairs, all_inst_pairs);

	display_report_summary_header_NE(entry);
	display_inst_pairs(sorted_inst_pairs);

	table_destroy(all_inst_pairs);
	table_destroy(sorted_inst_pairs);
}

static
void
display_report_summary_header_NE(Catalog_entry *entry)
{
	Class_def *class_def;
	Slot_def *slot_def;
	
	fprintf(MUC_report_summary_file,
		"%sDoc %s\n",
		MUC_report_comment_string,
		(entry->docnum) ? (entry->docnum) : "???");

	fprintf(MUC_report_summary_file,
		"%sTAG%s",
		MUC_report_comment_string,
		MUC_report_field_separator);
	
	table_first(MUC_Class_defs);
	class_def = (Class_def *)table_next(MUC_Class_defs);
	if( class_def )
	{
		table_first(class_def->slot_defs);
		while(slot_def=(Slot_def*)table_next(class_def->slot_defs))
			fprintf(MUC_report_summary_file,
				"%s%s%s%s",
				(slot_def->name) ? (slot_def->name) : "",
				MUC_report_field_separator,
				MUC_report_field_separator,
				MUC_report_field_separator);
	}
	fprintf(MUC_report_summary_file,"\n");
}


static
void
get_all_inst_pairs(TABLE *all_inst_pairs, TABLE *clas_pairs)
{
	Clas_pair *clas_pair;
	TABLE *inst_pairs;
	Inst_pair *inst_pair;
	
	table_first(clas_pairs);
	for(clas_pair=(Clas_pair *)table_next(clas_pairs);
	    clas_pair;
	    clas_pair=(Clas_pair *)table_next(clas_pairs))
	{
		inst_pairs = clas_pair->inst_pairs;
		table_first(inst_pairs);
		for(inst_pair=(Inst_pair *)table_next(inst_pairs);
		    inst_pair;
		    inst_pair=(Inst_pair *)table_next(inst_pairs))
			table_append((char *)inst_pair, 
				     all_inst_pairs);
	}
}

static
void
display_inst_pairs(TABLE *inst_pairs)
{
	Inst_pair *inst_pair;

	table_first(inst_pairs);
	for(inst_pair=(Inst_pair *)table_next(inst_pairs);
	    inst_pair;
	    inst_pair=(Inst_pair *)table_next(inst_pairs))
		display_inst_pair(inst_pair);
}


static
void
display_inst_pair(Inst_pair *inst_pair)
{
	Class_def *class_def;
	Slot_def *slot_def;
	Slot_pair *slot_pair;
	char *classname;

	if( inst_pair == NULL ) return;

	/* get the name of the inst */
	if(inst_pair->key_inst
	   &&
	   inst_pair->key_inst->name)
		classname = inst_pair->key_inst->name;
	else if(inst_pair->response_inst
		&&
		inst_pair->response_inst->name)
		classname = inst_pair->response_inst->name;
	else
		classname = "???";
	
	fprintf(MUC_report_summary_file,
		"%s%s",
		classname,
		MUC_report_field_separator
		);

	table_first(MUC_Class_defs);
	class_def = (Class_def *)table_next(MUC_Class_defs);
	if( class_def )
	{
		table_first(class_def->slot_defs);
		while(slot_def=(Slot_def*)table_next(class_def->slot_defs))
			if(slot_def->name)
			{
				slot_pair=slot_pair_find(inst_pair->slot_pairs,
							 slot_def->name);
				display_slot_pair(slot_pair);
			}
	}
	fprintf(MUC_report_summary_file,"\n");
}

static
void
display_slot_pair(Slot_pair *slot_pair)
{
	Sfil_pair *sfil_pair;
	
	if(slot_pair && slot_pair->mfil_pairs)
	{
		sfil_pair=get_scored_sfil_pair(slot_pair->mfil_pairs);
		display_sfil_pair(sfil_pair);
	}
	else
		fprintf(MUC_report_summary_file,
			"%s%s%s",
			MUC_report_field_separator,
			MUC_report_field_separator,
			MUC_report_field_separator);
}
		
static
void
display_sfil_pair(Sfil_pair *sfil_pair)
{
	char status_string[4];
	char *key_string_rep;
	char *rsp_string_rep;
	
	if(sfil_pair)
	{
		make_status_string(sfil_pair->status,status_string);
		key_string_rep=sfil_get_string_rep(sfil_pair->key_sfil);
		rsp_string_rep=sfil_get_string_rep(sfil_pair->response_sfil);
		fprintf(MUC_report_summary_file,
			"%s%s%s%s%s%s",
			status_string,
			MUC_report_field_separator,
			(key_string_rep) ? key_string_rep : "",
			MUC_report_field_separator,
			(rsp_string_rep) ? rsp_string_rep : "",
			MUC_report_field_separator);
	}
	else
		fprintf(MUC_report_summary_file,
			"%s%s%s",
			MUC_report_field_separator,
			MUC_report_field_separator,
			MUC_report_field_separator);
}	

static
void
make_status_string(char status,
		   char *status_string)
{
	*status_string='\0';

	switch(status)
	{
	case COR:
		strcat(status_string,
		       "cor");
		break;
	case INC:
		strcat(status_string,
		       "inc");
		break;
	case PAR:
		strcat(status_string,
		       "par");
		break;
	case MIS:
		strcat(status_string,
		       "mis");
		break;
	case SPU:
		strcat(status_string,
		       "spu");
		break;
	case OPT:
		strcat(status_string,
		       "opt");
		break;
	case UNSCORED:
		strcat(status_string,
		       "uns");
		break;
	case NON:
		strcat(status_string,
		       "non");
		break;
	default:
		strcat(status_string,
		       "   ");
		break;
	}
}


/* returns the first sfil pair with a status flag that
   indicates it contributed to the POS/ACT/COR score */

static
Sfil_pair *
get_scored_sfil_pair(TABLE *mfil_pairs)
{
	Mfil_pair *mfil_pair;
	TABLE *sfil_pairs;
	Sfil_pair *sfil_pair;
	
		
	/* first look for a COR pair */
	table_first(mfil_pairs);
	while(mfil_pair=(Mfil_pair *)table_next(mfil_pairs))
	{
		sfil_pairs=mfil_pair->sfil_pairs;
		table_first(sfil_pairs);
		sfil_pair=(Sfil_pair *)table_next(sfil_pairs);
		if(sfil_pair && (sfil_pair->status==COR))
			return sfil_pair;
	}
	/* then try a PAR pair */
	table_first(mfil_pairs);
	while(mfil_pair=(Mfil_pair *)table_next(mfil_pairs))
	{
		sfil_pairs=mfil_pair->sfil_pairs;
		table_first(sfil_pairs);
		sfil_pair=(Sfil_pair *)table_next(sfil_pairs);
		if(sfil_pair && (sfil_pair->status==PAR))
			return sfil_pair;
	}
	/* otherwise just take the first thing you see */
	table_first(mfil_pairs);
	while(mfil_pair=(Mfil_pair *)table_next(mfil_pairs))
	{
		sfil_pairs=mfil_pair->sfil_pairs;
		table_first(sfil_pairs);
		sfil_pair=(Sfil_pair *)table_next(sfil_pairs);
		return sfil_pair;
	}
	/* In case mfil_pairs is empty... */
	return NULL;
}

