/*
 *  Copyright 1995 Science Applications International Corporation.
 */

/*
 * NAME
 *
 * 
 * FILE 
 *	setfill.c
 *
 * SYNOPSIS
 *
 *
 * DESCRIPTION
 *	support routines for setfill data structure.
 *
 * DIAGNOSTICS
 *
 *
 * FILES
 *
 *
 * NOTES
 *	Scratch pad - modification history, plans for enhancements.
 * 
 * SEE ALSO
 *
 * AUTHOR
 *	Gary Dungca	August 1995
 *
 */


#ifdef SCCSID
static char SccsId[] = "@(#)setfill.c	22.1\t12/08/98\tSAIC";
#endif

#undef SCCSID
#include  "muc_defs.h"
#include  "muc.h"
#include  "muc_protos.h"
#include  "muc_globals.h"

/************************************************************************
 *									*
 *  setfill_create
 *									*
 ***********************************************************************/

Setfill *
setfill_create(void)
{
    Setfill *new_setfill;
    
    if((new_setfill = UALLOC(Setfill, 1)) == (Setfill *)NULL)
    {
	fprintf(stderr, "Error: [setfill_create]: Allocation failed.\n");
	exit(1);
    }

    new_setfill->fill = NULL;
    new_setfill->start_offset = 0;
    new_setfill->end_offset = 0;
    
    return(new_setfill);
}

Setfill *
setfill_create_from_attribute(char *tokenstart, char *tokenfinish)
{
	Setfill *result;

	result = setfill_create();
	result->fill = alloc_between(tokenstart, tokenfinish);
	return result;
}


/************************************************************************
 *									*
 *  setfill_release							*
 *									*
 ***********************************************************************/

void
setfill_release(char *c_ptr)
{
    Setfill *setfill = (Setfill *)c_ptr;
    
    if(setfill == (Setfill *)NULL)
	return;
    
    UFREE(setfill->fill);
    UFREE(setfill);
}

/*********************************************************************
 * 
 * setfill_match -- comparees two setfills, and returns COR, INC
 *                  or PAR -- also increments the tallies data 
 *                  struct
 *
 ********************************************************************
 */

char
setfill_match(Setfill *key_setfill, 
	      Setfill *response_setfill,
	      Tallies *tallies)
{
  if(STRCASEEQ(key_setfill->fill, response_setfill->fill))
    {
      tally1_correct( tallies );
      return COR;
    }
  else
    {
      tally1_incorrect( tallies );
      return INC;
    }
}
     

/************************************************************************
 *									*
 * setfill_print
 *									*
 ***********************************************************************/

void
setfill_print(Setfill *setfill, int indent)
{
  printf("%*.s%s\n", indent, "", setfill->fill );
}
