/*
 *  Copyright 1995 Science Applications International Corporation.
 */

/*
 * NAME
 *
 * 
 * FILE 
 *	sfil.c
 *
 * SYNOPSIS
 *
 *
 * DESCRIPTION
 *	support routines for sfil (single fill) data structure.
 *
 * DIAGNOSTICS
 *
 *
 * FILES
 *
 *
 * NOTES
 * 
 * SEE ALSO
 *
 * AUTHOR
 *
 */


#ifdef SCCSID
static char SccsId[] = "@(#)sfil.c	22.1\t12/08/98\tSAIC";
#endif

#undef SCCSID
#include  "muc_defs.h"
#include  "muc.h"
#include  "muc_protos.h"
#include  "muc_globals.h"


/************************************************************************
 *									*
 *  sfil_create
 *									*
 ***********************************************************************/

Sfil *
sfil_create(int type)
{
    Sfil *new_sfil;
    
    if((new_sfil = UALLOC(Sfil, 1)) == NULL)
    {
	fprintf(stderr, "Error: [sfil_create]: Allocation failed.\n");
	exit(1);
    }

    new_sfil->type = type;  
    switch(type)
      {
      case SET_FILL:
	new_sfil->fill.set = setfill_create();
	break;
      case POINTER_FILL:
	new_sfil->fill.ptr = pointerfill_create();
	break;
      case STRING_FILL:
	new_sfil->fill.str = stringfill_create();
	break;
      case EXTENT_FILL:
	new_sfil->fill.ext = extentfill_create();
	break;
      case LEXSEQ_FILL:
	new_sfil->fill.lsq = lexseqfill_create();
	break;
      default:
	fprintf( stderr, "[sfil_create]: Unknown fill type\n" );
	exit(1);
	break;
      }

    return(new_sfil);
}

Sfil *
sfil_create_from_attribute(int type, char *tokenstart, char *tokenfinish)
{
	Sfil *result;
	
	if((result = UALLOC(Sfil, 1)) == NULL)
	{
		fprintf(stderr, "Error: [sfil_create]: Allocation failed.\n");
		exit(1);
	}
	
	result->type = type;  

	switch(type)
	{
	case STRING_FILL:
		result->fill.str = 
			stringfill_create_from_attribute(tokenstart,
							 tokenfinish);
		break;

	case SET_FILL:
		result->fill.set = 
			setfill_create_from_attribute(tokenstart,
						      tokenfinish);
		break;

	case POINTER_FILL:
		result->fill.ptr = 
			pointerfill_create_from_attribute(tokenstart,
							  tokenfinish);
		break;
		
	case EXTENT_FILL:
		result->fill.ext = 
			extentfill_create_from_attribute(tokenstart, 
							 tokenfinish);
		break;

	case LEXSEQ_FILL:
		result->fill.lsq = 
			lexseqfill_create_from_attribute(tokenstart, 
							 tokenfinish);
		break;

	default:
		fprintf(stderr,
			"Line %d:  Unknown slot fill type\n",
			MUC_cur_lineno);
		exit(1);
	}
	return result;
}


/************************************************************************
 *									*
 *  sfil_release							*
 *									*
 ***********************************************************************/

void
sfil_release(char *c_ptr)
{
    Sfil *sfil = (Sfil *)c_ptr;
    
    if(sfil == (Sfil *)NULL)
	return;
    
    switch(sfil->type)
      {
      case SET_FILL:
	setfill_release((char *)sfil->fill.set);
	break;
      case POINTER_FILL:
	pointerfill_release((char *)sfil->fill.ptr);
	break;
      case STRING_FILL:
	stringfill_release((char *)sfil->fill.str);
	break;
      case EXTENT_FILL:
	extentfill_release((char *)sfil->fill.ext);
	break;
      case LEXSEQ_FILL:
	lexseqfill_release((char *)sfil->fill.lsq);
	break;
      default:
	fprintf(stderr, "[sfil_release]: Unknown fill type\n" );
	exit(1);
	break;
      }
    UFREE(sfil);
}

/************************************************************************
 *									*
 *  sfil_compare							*
 *									*
 ***********************************************************************/

int
sfil_compare(char *item1, char *item2)
{
    return ((int)((char *) item1 - (char *) item2));
}


/************************************************************************
 *									*
 * sfil_clear_aligned_flags
 *									*
 ***********************************************************************/

int
sfil_clear_aligned_flags( TABLE *sfils )
{
  Sfil *sfil;
  
  table_first(sfils);
  for(sfil = (Sfil *)table_next(sfils);
      sfil;
      sfil = (Sfil *)table_next(sfils))
    sfil->is_aligned = False;
}


/************************************************************************
 *									*
 *  sfil_is_removed -- if a single fill is a pointer fill, and the 
 *                     instance it points to is an unaligned optional
 *                     instance, then the single fill shouldn't be there
 *                     and will be "removed"
 *									*
 ***********************************************************************/


Bool
sfil_is_removed(Sfil *sfil)
{
  if(   sfil 
     && sfil->type == POINTER_FILL
     && sfil->fill.ptr
     && sfil->fill.ptr->fill
     && sfil->fill.ptr->fill->its_pair
     && sfil->fill.ptr->fill->its_pair->status == OPT )
    return True;
  else
    return False;
}


/************************************************************************
 *									*
 * sfil_count_unaligned
 *									*
 ***********************************************************************/

int
sfil_count_unaligned( TABLE *sfils )
{
  Sfil *sfil;
  int num_unaligned = 0;
  
  table_first(sfils);
  for(sfil = (Sfil *)table_next(sfils);
      sfil;
      sfil = (Sfil *)table_next(sfils))
    if( !sfil->is_aligned )
      num_unaligned++;
  return num_unaligned;

}

/************************************************************************
 *									*
 * sfil_get_string_rep
 *									*
 ***********************************************************************/

char *
sfil_get_string_rep(Sfil *sfil)
{
	if( sfil )
		switch(sfil->type)
		{
		case SET_FILL:
			if( sfil->fill.set )
				return sfil->fill.set->fill;
		case POINTER_FILL:
			if( sfil->fill.ptr )
				return sfil->fill.ptr->string_rep;
		case STRING_FILL:
			if( sfil->fill.str )
				return sfil->fill.str->fill;
		case EXTENT_FILL:
			if( sfil->fill.ext )
				return sfil->fill.ext->string_rep;
		case LEXSEQ_FILL:
			if( sfil->fill.lsq )
				return sfil->fill.lsq->string_rep;
		}
	return NULL;
}

void
sfil_make_string_rep(Sfil *sfil)
{
	char *string_rep;
	
	if( sfil )
		switch(sfil->type)
		{
		case SET_FILL:
		case POINTER_FILL:
		case STRING_FILL:
			break;
		case EXTENT_FILL:
			if( sfil->fill.ext )
				extentfill_make_string_rep(sfil->fill.ext);
			break;

		case LEXSEQ_FILL:
			if( sfil->fill.lsq )
				lexseqfill_make_string_rep( sfil->fill.lsq );
			break;
		}
}

/************************************************************************
 *									*
 * sfil_print_table
 *									*
 ***********************************************************************/

void
sfil_print_table(TABLE *sfils, int indent)
{
  Sfil *sfil;
  table_first( sfils );
  for(sfil = (Sfil *)table_next(sfils);
      sfil;
      sfil = (Sfil *)table_next(sfils))
    sfil_print( sfil, indent );
}


/************************************************************************
 *									*
 * sfil_print
 *									*
 ***********************************************************************/

void
sfil_print(Sfil *sfil, int indent)
{
  switch(sfil->type)
    {
    case SET_FILL:
      setfill_print(sfil->fill.set, indent);
      break;
    case POINTER_FILL:
      pointerfill_print(sfil->fill.ptr, indent);
      break;
    case STRING_FILL:
      stringfill_print(sfil->fill.str, indent);
      break;
    case EXTENT_FILL:
      extentfill_print(sfil->fill.ext, indent);
      break;
    case LEXSEQ_FILL:
      lexseqfill_print(sfil->fill.lsq, indent);
      break;
    default:
      fprintf( stderr, "[sfil_print]: Unknown fill type: %d\n", sfil->type );
      break;
    }
}
