 /* file aldistsm.c */

#if !defined(COMPILE_ENVIRONMENT)
#include <gp/stdcenvf.h> /* std compile environment for functions */
#endif

 /**********************************************************************/
 /*                                                                    */
 /*   int aldistsm(pt1,w,return_alignment,fom_threshold,pt2,perr)      */
 /*                                                                    */
 /*   ALIGNMENT_INT *pt1, *pt2; int (*w)(int*,int*,pcodeset*);         */
 /*   boolean return_alignment; int *perr;                             */
 /*   double fom_threshold;                                            */
 /*                                                                    */
 /*    Computes and returns the alignment distance between the         */
 /* symbols in the two integer strings in *pt1 (aint[] and bint[]).    */
 /* This version considers splits and merges, recursively, using the   */
 /* value of "fom_threshold".                                          */
 /* If a split or merge is found, an auxiliary symbol representing two */
 /* or more pcode symbols is put into the aux table of pt2.            */
 /* W(i,j) is a pointer to an integer cost (weight or distance)        */
 /* function of two integer variables and a pcodeset, which returns    */
 /* the distance from symbol i to j.                                   */
 /* w(i,j) is the cost of substituting int j for int i.                */
 /* w(0,j) is the cost of inserting int j;                             */
 /* w(i,0) is the cost of deleting int j;                              */
 /*    If <return_alignment> is T, this function returns as a          */
 /* by-product the particular alignment found, in *pt2.  The two       */
 /* strings in *pt2 will have been put into alignment by inserting     */
 /* nulls (zero) into one or both of them.                             */
 /*                                                                    */
 /*   *perr = 0 means a.o.k.                                           */
 /*   error codes:                                                     */
 /*   11:invalid input parameters                                      */
 /*                                                                    */
 /**********************************************************************/

  int aldistsm(ALIGNMENT_INT *aln_in, int (*w) (int,int,pcodeset*,int*),
      int return_alignment, double fom_threshold, ALIGNMENT_INT *aln_out,
      int *perr)
   {/* data: */
    char *proc = "aldistsm";
    pcodeset *pcode1;
    short int d, dx;
    int smdel, sm_corr;
    boolean return_simple_alignment = T;
    boolean error_check = F;
    ALIGNMENT_INT *alnx;
    SM_TAB_STR2 smtabx, *smtab = &smtabx;
    /* used only if error checking is on: */
    ALIGNMENT_INT *aln_basic_bef, *aln_basic_aft;
/* code: */
 /**** start debug ****/
db_enter_msg(proc,0); /* debug only */
if (db_level > 0 )
   {if (return_alignment) printf("%s return_alignment = T\n",pdb);
    else                  printf("%s return_alignment = F\n",pdb);
    printf("*DB:   the pcode is '%s'\n",(aln_in->pcset)->name);
    printf("*DB:   na =%d, nb =%d\n",aln_in->aint[0],aln_in->bint[0]);
    printf("*DB:   the input strings to align are:\n\n");
    dump_int_alignment(aln_in);
   }
 /**** debug ****/

 /* initialize */
  *perr=0;
  d=0;
  pcode1 = aln_in->pcset;
  if (return_alignment) alnx = aln_out;
  else                  alnx = make_al_int(pcode1);
  if (error_check)
    {aln_basic_bef = make_al_int(pcode1);
     aln_basic_aft = make_al_int(pcode1);
    }
/* start with a non-sm alignment: */
  d = aldist2(aln_in,w,return_simple_alignment,alnx,perr);
/*  if (*perr > 0)  fprintf(stderr,"%s: aldist2() returns err = %d\n",proc,*perr);*/
  if (*perr > 10) goto RETURN;

if (db_level > 0)
 {printf("%s simple alignment (aldist2) d=%d\n",pdb,d);
  printf("%s simple alignment (static)  d=%d\n",pdb,aldist_static(alnx,perr));
/*  if (*perr > 0)  fprintf(stderr,"%s: aldist_static() returns err = %d\n",proc,*perr);*/
  if (*perr > 10) goto RETURN;
  printf("%s phon alignment is:\n",pdb);
  dump_int_alignment4(alnx);
 }

/* modify it to represent splits and merges: */
if (db_level > 0) printf("%s now modifying it to represent splits/merges.\n",pdb);
  smtab->nsaved = 0;
  smtab->nover  = 0;
  alnx->naux    = 0;
  sm_corr       = 0;
  if (error_check)
    {aln_basic_bef = copy_int_al(aln_basic_bef,alnx);
     make_basic_int_al(aln_basic_bef);
    }
  while ((smdel = sm_correction2(alnx,fom_threshold,smtab,perr)) > 0)
    {sm_corr += smdel;
     sort_sm_by_iloc(smtab);
     put_sm_into_aln(alnx,smtab,perr);
     if (error_check)
       {/* see if basic alnx was altered */
        aln_basic_aft = copy_int_al(aln_basic_aft,alnx);
        make_basic_int_al(aln_basic_aft);
        if ((!nstreq(aln_basic_bef->aint,aln_basic_aft->aint))
          ||(!nstreq(aln_basic_bef->bint,aln_basic_aft->bint)))         
          {printf("*WARNING:%s: sm procedure changed basic alignment.\n",proc);
           printf("Basic alignment before =\n");
           dump_int_alignment(aln_basic_bef);
           printf("Basic alignment after =\n");
           dump_int_alignment(aln_basic_aft);
          }
        aln_basic_bef = copy_int_al(aln_basic_bef,aln_basic_aft);
       } /* end error check processing */
    }
  d -= sm_corr;

if (error_check)
  {/*** check is dynamically-calculated d = static d ***/
   dx = aldist_static(alnx,perr);
   if (dx != d)
     {printf("*ERR:%s:sm1 sm_corr not correct.\n",proc);
      printf(" d=%d, dx(from aldist_static)=%d\n",d,dx);
  }  }

RETURN:

if (db_level > 1)
  {printf("%s at exit, alnx=\n",pdb);
   dump_int_alignment4(alnx);
  }

  if (!return_alignment) free_al_int(alnx);
  if (error_check)
    {free_al_int(aln_basic_bef);
     free_al_int(aln_basic_aft);
    }

 db_leave_msg(proc,0); /* debug only */

  return d;
  } /* end of function "aldistsm" */
 /* end of file "aldistsm.c" */
